package X11::XRTCons;
package X::XRT;
sub XRT_VERSION () { 3 }
sub XRT_REVISION () { 0 }
sub XRT_POINT () { 0 }
sub XRT_RELEASE () { 3000 }
sub XRTGEAR_VERSION () { 2 }
sub XRTGEAR_REVISION () { 0 }
sub XRTGEAR_POINT () { 1 }
sub XRTGEAR_RELEASE () { 2001 }
sub XRT_GRAPH_CHANGED () { 1 }
sub XRT_HEADER_CHANGED () { 2 }
sub XRT_FOOTER_CHANGED () { 4 }
sub XRT_LEGEND_CHANGED () { 8 }
sub XRT_MARKER_CHANGED () { 16 }
sub XRT_DATA_CHANGED () { 9 }
sub XRT_ALL_CHANGED () { 255 }
sub XRTT_NONE () { 0 }
sub XRTT_BOOLVAL () { 1 }
sub XRTT_COLOR () { 2 }
sub XRTT_DATA () { 3 }
sub XRTT_DATA_STYLE () { 4 }
sub XRTT_DATA_STYLES () { 5 }
sub XRTT_DIMENSION () { 6 }
sub XRTT_FLOAT () { 7 }
sub XRTT_FONT () { 8 }
sub XRTT_INT () { 9 }
sub XRTT_LONG () { 10 }
sub XRTT_POSITION () { 11 }
sub XRTT_STRING () { 12 }
sub XRTT_STRINGS () { 13 }
sub XRTT_USE_DEFAULT () { 14 }
sub XRTT_VALUE_LABELS () { 15 }
sub XRTT_ADJUST () { 64 }
sub XRTT_ALIGN () { 65 }
sub XRTT_ANCHOR () { 66 }
sub XRTT_ANNO_METHOD () { 67 }
sub XRTT_ANNO_PLACEMENT () { 68 }
sub XRTT_BORDER () { 69 }
sub XRTT_DATASET () { 70 }
sub XRTT_DATA_TYPE () { 71 }
sub XRTT_FILL_PATTERN () { 72 }
sub XRTT_LINE_PATTERN () { 73 }
sub XRTT_NUM_METHOD () { 74 }
sub XRTT_ORIGIN_PLACEMENT () { 75 }
sub XRTT_PIE_ORDER () { 76 }
sub XRTT_PIE_THRESHOLD_METHOD () { 77 }
sub XRTT_POINT () { 78 }
sub XRTT_ROTATE () { 79 }
sub XRTT_TIME_UNIT () { 80 }
sub XRTT_TYPE () { 81 }
sub XRTT_MARKER_METHOD () { 82 }
sub XRTT_TEXT_ATTACH () { 83 }
sub XRTT_SHADING () { 84 }
sub XRTT_ANGLE_UNIT () { 85 }
sub XRT_DOUBLE_BUFFER () { 256 }
sub XRT_LEGEND_SHOW () { 257 }
sub XRT_XAXIS_SHOW () { 258 }
sub XRT_YAXIS_SHOW () { 259 }
sub XRT_Y2AXIS_SHOW () { 260 }
sub XRT_INVERT_ORIENTATION () { 261 }
sub XRT_TRANSPOSE_DATA () { 262 }
sub XRT_XMARKER_SHOW () { 263 }
sub XRT_YMARKER_SHOW () { 264 }
sub XRT_AXIS_BOUNDING_BOX () { 265 }
sub XRT_XAXIS_LOGARITHMIC () { 266 }
sub XRT_YAXIS_LOGARITHMIC () { 267 }
sub XRT_Y2AXIS_LOGARITHMIC () { 268 }
sub XRT_XAXIS_REVERSED () { 269 }
sub XRT_YAXIS_REVERSED () { 270 }
sub XRT_Y2AXIS_REVERSED () { 271 }
sub XRT_DEBUG () { 272 }
sub XRT_REPAINT () { 273 }
sub XRT_CANDLE_COMPLEX () { 274 }
sub XRT_HILO_CLOSE_SHOW () { 275 }
sub XRT_HILO_OPEN_SHOW () { 276 }
sub XRT_HILO_OPEN_CLOSE_FULL_WIDTH () { 277 }
sub XRT_POLAR_HALF_RANGE () { 278 }
sub XRT_YAXIS_100_PERCENT () { 279 }
sub XRT_Y2AXIS_100_PERCENT () { 280 }
sub XRT_GRAPH_SHOW_OUTLINES () { 281 }
sub XRT_TEXT_IS_CONNECTED () { 282 }
sub XRT_TEXT_IS_SHOWING () { 283 }
sub XRT_GRAPH_X () { 2816 }
sub XRT_GRAPH_Y () { 2817 }
sub XRT_HEADER_X () { 2818 }
sub XRT_HEADER_Y () { 2819 }
sub XRT_FOOTER_X () { 2820 }
sub XRT_FOOTER_Y () { 2821 }
sub XRT_LEGEND_X () { 2822 }
sub XRT_LEGEND_Y () { 2823 }
sub XRT_GRAPH_MARGIN_BOTTOM () { 2824 }
sub XRT_GRAPH_MARGIN_LEFT () { 2825 }
sub XRT_GRAPH_MARGIN_RIGHT () { 2826 }
sub XRT_GRAPH_MARGIN_TOP () { 2827 }
sub XRT_TEXT_X () { 2828 }
sub XRT_TEXT_Y () { 2829 }
sub XRT_TEXT_ATTACH_PIXEL_X () { 2830 }
sub XRT_TEXT_ATTACH_PIXEL_Y () { 2831 }
sub XRT_GRAPH_WIDTH () { 1536 }
sub XRT_GRAPH_HEIGHT () { 1537 }
sub XRT_HEADER_WIDTH () { 1538 }
sub XRT_HEADER_HEIGHT () { 1539 }
sub XRT_FOOTER_WIDTH () { 1540 }
sub XRT_FOOTER_HEIGHT () { 1541 }
sub XRT_LEGEND_WIDTH () { 1542 }
sub XRT_LEGEND_HEIGHT () { 1543 }
sub XRT_BORDER_WIDTH () { 1544 }
sub XRT_HEADER_BORDER_WIDTH () { 1545 }
sub XRT_FOOTER_BORDER_WIDTH () { 1546 }
sub XRT_GRAPH_BORDER_WIDTH () { 1547 }
sub XRT_LEGEND_BORDER_WIDTH () { 1548 }
sub XRT_WIDTH () { 1549 }
sub XRT_HEIGHT () { 1550 }
sub XRT_TEXT_WIDTH () { 1551 }
sub XRT_TEXT_HEIGHT () { 1552 }
sub XRT_TEXT_BORDER_WIDTH () { 1553 }
sub XRT_XPRECISION () { 2304 }
sub XRT_YPRECISION () { 2305 }
sub XRT_Y2PRECISION () { 2306 }
sub XRT_PIE_MIN_SLICES () { 2307 }
sub XRT_XMARKER_SET () { 2308 }
sub XRT_XMARKER_POINT () { 2309 }
sub XRT_BAR_CLUSTER_OVERLAP () { 2310 }
sub XRT_BAR_CLUSTER_WIDTH () { 2311 }
sub XRT_GRAPH_DEPTH () { 2312 }
sub XRT_GRAPH_ROTATION () { 2313 }
sub XRT_GRAPH_INCLINATION () { 2314 }
sub XRT_TEXT_ATTACH_SET () { 2315 }
sub XRT_TEXT_ATTACH_POINT () { 2316 }
sub XRT_TEXT_OFFSET () { 2317 }
sub XRT_TIME_BASE () { 2560 }
sub XRT_BACKGROUND_COLOR () { 512 }
sub XRT_FOREGROUND_COLOR () { 513 }
sub XRT_GRAPH_BACKGROUND_COLOR () { 514 }
sub XRT_GRAPH_FOREGROUND_COLOR () { 515 }
sub XRT_HEADER_BACKGROUND_COLOR () { 516 }
sub XRT_HEADER_FOREGROUND_COLOR () { 517 }
sub XRT_FOOTER_BACKGROUND_COLOR () { 518 }
sub XRT_FOOTER_FOREGROUND_COLOR () { 519 }
sub XRT_LEGEND_BACKGROUND_COLOR () { 520 }
sub XRT_LEGEND_FOREGROUND_COLOR () { 521 }
sub XRT_DATA_AREA_BACKGROUND_COLOR () { 522 }
sub XRT_DATA_AREA_FOREGROUND_COLOR () { 523 }
sub XRT_TEXT_BACKGROUND_COLOR () { 524 }
sub XRT_TEXT_FOREGROUND_COLOR () { 525 }
sub XRT_TYPE () { 20736 }
sub XRT_TYPE2 () { 20737 }
sub XRT_HEADER_ADJUST () { 16384 }
sub XRT_FOOTER_ADJUST () { 16385 }
sub XRT_TEXT_ADJUST () { 16386 }
sub XRT_PIE_ORDER () { 19456 }
sub XRT_PIE_THRESHOLD_METHOD () { 19712 }
sub XRT_LEGEND_ANCHOR () { 16896 }
sub XRT_TEXT_ANCHOR () { 16897 }
sub XRT_LEGEND_ORIENTATION () { 16640 }
sub XRT_BORDER () { 17664 }
sub XRT_HEADER_BORDER () { 17665 }
sub XRT_FOOTER_BORDER () { 17666 }
sub XRT_LEGEND_BORDER () { 17667 }
sub XRT_GRAPH_BORDER () { 17668 }
sub XRT_TEXT_BORDER () { 17669 }
sub XRT_XANNOTATION_METHOD () { 17152 }
sub XRT_YANNOTATION_METHOD () { 17153 }
sub XRT_Y2ANNOTATION_METHOD () { 17154 }
sub XRT_XANNO_PLACEMENT () { 17408 }
sub XRT_YANNO_PLACEMENT () { 17409 }
sub XRT_Y2ANNO_PLACEMENT () { 17410 }
sub XRT_XNUM_METHOD () { 18944 }
sub XRT_YNUM_METHOD () { 18945 }
sub XRT_Y2NUM_METHOD () { 18946 }
sub XRT_XORIGIN_PLACEMENT () { 19200 }
sub XRT_YORIGIN_PLACEMENT () { 19201 }
sub XRT_Y2ORIGIN_PLACEMENT () { 19202 }
sub XRT_TIME_UNIT () { 20480 }
sub XRT_XTITLE_ROTATION () { 20224 }
sub XRT_YTITLE_ROTATION () { 20225 }
sub XRT_Y2TITLE_ROTATION () { 20226 }
sub XRT_XANNOTATION_ROTATION () { 20227 }
sub XRT_YANNOTATION_ROTATION () { 20228 }
sub XRT_Y2ANNOTATION_ROTATION () { 20229 }
sub XRT_TEXT_ROTATION () { 20230 }
sub XRT_FRONT_DATASET () { 17920 }
sub XRT_MARKER_DATASET () { 17921 }
sub XRT_TEXT_ATTACH_DATASET () { 17922 }
sub XRT_XMARKER_METHOD () { 20992 }
sub XRT_TEXT_ATTACH_TYPE () { 21248 }
sub XRT_GRAPH_3D_SHADING () { 21504 }
sub XRT_ANGLE_UNIT () { 21760 }
sub XRT_XTITLE () { 3072 }
sub XRT_YTITLE () { 3073 }
sub XRT_Y2TITLE () { 3074 }
sub XRT_OTHER_LABEL () { 3075 }
sub XRT_TIME_FORMAT () { 3076 }
sub XRT_XAXIS_LABEL_FORMAT () { 3077 }
sub XRT_YAXIS_LABEL_FORMAT () { 3078 }
sub XRT_Y2AXIS_LABEL_FORMAT () { 3079 }
sub XRT_TEXT_NAME () { 3080 }
sub XRT_TEXT_PRINT_FONT () { 3081 }
sub XRT_DATA () { 768 }
sub XRT_DATA2 () { 769 }
sub XRT_AXIS_FONT () { 2048 }
sub XRT_HEADER_FONT () { 2049 }
sub XRT_FOOTER_FONT () { 2050 }
sub XRT_LEGEND_FONT () { 2051 }
sub XRT_TEXT_FONT () { 2052 }
sub XRT_OTHER_DATA_STYLE () { 1024 }
sub XRT_MARKER_DATA_STYLE () { 1025 }
sub XRT_XGRID_DATA_STYLE () { 1026 }
sub XRT_YGRID_DATA_STYLE () { 1027 }
sub XRT_Y2GRID_DATA_STYLE () { 1028 }
sub XRT_XMARKER_DATA_STYLE () { 1029 }
sub XRT_YMARKER_DATA_STYLE () { 1030 }
sub XRT_XMIN () { 1792 }
sub XRT_YMIN () { 1793 }
sub XRT_Y2MIN () { 1794 }
sub XRT_XMAX () { 1795 }
sub XRT_YMAX () { 1796 }
sub XRT_Y2MAX () { 1797 }
sub XRT_XNUM () { 1798 }
sub XRT_YNUM () { 1799 }
sub XRT_Y2NUM () { 1800 }
sub XRT_XTICK () { 1801 }
sub XRT_YTICK () { 1802 }
sub XRT_Y2TICK () { 1803 }
sub XRT_XORIGIN () { 1804 }
sub XRT_YORIGIN () { 1805 }
sub XRT_PIE_THRESHOLD_VALUE () { 1806 }
sub XRT_XMARKER () { 1807 }
sub XRT_YMARKER () { 1808 }
sub XRT_XGRID () { 1809 }
sub XRT_YGRID () { 1810 }
sub XRT_XAXIS_MAX () { 1811 }
sub XRT_YAXIS_MAX () { 1812 }
sub XRT_Y2AXIS_MAX () { 1813 }
sub XRT_XAXIS_MIN () { 1814 }
sub XRT_YAXIS_MIN () { 1815 }
sub XRT_Y2AXIS_MIN () { 1816 }
sub XRT_YAXIS_MULT () { 1817 }
sub XRT_YAXIS_CONST () { 1818 }
sub XRT_Y2ORIGIN () { 1819 }
sub XRT_Y2GRID () { 1820 }
sub XRT_TEXT_ATTACH_VALUE_X () { 1821 }
sub XRT_TEXT_ATTACH_VALUE_Y () { 1822 }
sub XRT_XORIGIN_BASE () { 1823 }
sub XRT_YANNOTATION_ANGLE () { 1824 }
sub XRT_Y2ANNOTATION_ANGLE () { 1825 }
sub XRT_DATA_STYLES () { 1280 }
sub XRT_DATA_STYLES2 () { 1281 }
sub XRT_SET_LABELS () { 3328 }
sub XRT_SET_LABELS2 () { 3329 }
sub XRT_POINT_LABELS () { 3330 }
sub XRT_POINT_LABELS2 () { 3331 }
sub XRT_HEADER_STRINGS () { 3332 }
sub XRT_FOOTER_STRINGS () { 3333 }
sub XRT_TEXT_STRINGS () { 3334 }
sub XRT_XLABELS () { 3840 }
sub XRT_YLABELS () { 3841 }
sub XRT_Y2LABELS () { 3842 }
sub XRT_GRAPH_X_USE_DEFAULT () { 3584 }
sub XRT_GRAPH_Y_USE_DEFAULT () { 3585 }
sub XRT_GRAPH_WIDTH_USE_DEFAULT () { 3586 }
sub XRT_GRAPH_HEIGHT_USE_DEFAULT () { 3587 }
sub XRT_HEADER_X_USE_DEFAULT () { 3588 }
sub XRT_HEADER_Y_USE_DEFAULT () { 3589 }
sub XRT_FOOTER_X_USE_DEFAULT () { 3590 }
sub XRT_FOOTER_Y_USE_DEFAULT () { 3591 }
sub XRT_LEGEND_X_USE_DEFAULT () { 3592 }
sub XRT_LEGEND_Y_USE_DEFAULT () { 3593 }
sub XRT_XMAX_USE_DEFAULT () { 3594 }
sub XRT_YMAX_USE_DEFAULT () { 3595 }
sub XRT_Y2MAX_USE_DEFAULT () { 3596 }
sub XRT_XMIN_USE_DEFAULT () { 3597 }
sub XRT_YMIN_USE_DEFAULT () { 3598 }
sub XRT_Y2MIN_USE_DEFAULT () { 3599 }
sub XRT_XTICK_USE_DEFAULT () { 3600 }
sub XRT_YTICK_USE_DEFAULT () { 3601 }
sub XRT_Y2TICK_USE_DEFAULT () { 3602 }
sub XRT_XNUM_USE_DEFAULT () { 3603 }
sub XRT_YNUM_USE_DEFAULT () { 3604 }
sub XRT_Y2NUM_USE_DEFAULT () { 3605 }
sub XRT_XORIGIN_USE_DEFAULT () { 3606 }
sub XRT_YORIGIN_USE_DEFAULT () { 3607 }
sub XRT_DATA_STYLES_USE_DEFAULT () { 3608 }
sub XRT_DATA_STYLES2_USE_DEFAULT () { 3609 }
sub XRT_OTHER_DATA_STYLE_USE_DEFAULT () { 3610 }
sub XRT_MARKER_DATA_STYLE_USE_DEFAULT () { 3611 }
sub XRT_XGRID_DATA_STYLE_USE_DEFAULT () { 3612 }
sub XRT_YGRID_DATA_STYLE_USE_DEFAULT () { 3613 }
sub XRT_XGRID_USE_DEFAULT () { 3614 }
sub XRT_YGRID_USE_DEFAULT () { 3615 }
sub XRT_XPRECISION_USE_DEFAULT () { 3616 }
sub XRT_YPRECISION_USE_DEFAULT () { 3617 }
sub XRT_Y2PRECISION_USE_DEFAULT () { 3618 }
sub XRT_GRAPH_MARGIN_BOTTOM_USE_DEFAULT () { 3619 }
sub XRT_GRAPH_MARGIN_LEFT_USE_DEFAULT () { 3620 }
sub XRT_GRAPH_MARGIN_RIGHT_USE_DEFAULT () { 3621 }
sub XRT_GRAPH_MARGIN_TOP_USE_DEFAULT () { 3622 }
sub XRT_XAXIS_MAX_USE_DEFAULT () { 3623 }
sub XRT_YAXIS_MAX_USE_DEFAULT () { 3624 }
sub XRT_Y2AXIS_MAX_USE_DEFAULT () { 3625 }
sub XRT_XAXIS_MIN_USE_DEFAULT () { 3626 }
sub XRT_YAXIS_MIN_USE_DEFAULT () { 3627 }
sub XRT_Y2AXIS_MIN_USE_DEFAULT () { 3628 }
sub XRT_TIME_FORMAT_USE_DEFAULT () { 3629 }
sub XRT_XMARKER_DATA_STYLE_USE_DEFAULT () { 3630 }
sub XRT_YMARKER_DATA_STYLE_USE_DEFAULT () { 3631 }
sub XRT_Y2ORIGIN_USE_DEFAULT () { 3632 }
sub XRT_Y2GRID_USE_DEFAULT () { 3633 }
sub XRT_Y2GRID_DATA_STYLE_USE_DEFAULT () { 3634 }
sub XRT_YANNOTATION_ANGLE_USE_DEFAULT () { 3635 }
sub XRT_Y2ANNOTATION_ANGLE_USE_DEFAULT () { 3636 }
sub XRT_ADJUST_LEFT () { 1 }
sub XRT_ADJUST_RIGHT () { 2 }
sub XRT_ADJUST_CENTER () { 3 }
sub XRT_ALIGN_VERTICAL () { 1 }
sub XRT_ALIGN_HORIZONTAL () { 2 }
sub XRT_ANCHOR_NORTH () { 16 }
sub XRT_ANCHOR_SOUTH () { 32 }
sub XRT_ANCHOR_EAST () { 1 }
sub XRT_ANCHOR_WEST () { 2 }
sub XRT_ANCHOR_NORTHEAST () { 17 }
sub XRT_ANCHOR_NORTHWEST () { 18 }
sub XRT_ANCHOR_SOUTHEAST () { 33 }
sub XRT_ANCHOR_SOUTHWEST () { 34 }
sub XRT_ANCHOR_HOME () { 0 }
sub XRT_ANCHOR_BEST () { 256 }
sub XRT_ANGLE_DEGREES () { 1 }
sub XRT_ANGLE_RADIANS () { 2 }
sub XRT_ANGLE_GRADS () { 3 }
sub XRT_ANNO_VALUES () { 0 }
sub XRT_ANNO_POINT_LABELS () { 1 }
sub XRT_ANNO_VALUE_LABELS () { 2 }
sub XRT_ANNO_TIME_LABELS () { 3 }
sub XRT_ANNO_AUTO () { 0 }
sub XRT_ANNO_ORIGIN () { 1 }
sub XRT_ANNO_MIN () { 2 }
sub XRT_ANNO_MAX () { 3 }
sub XRT_TEXT_ATTACH_PIXEL () { 0 }
sub XRT_TEXT_ATTACH_VALUE () { 1 }
sub XRT_TEXT_ATTACH_DATA () { 2 }
sub XRT_TEXT_ATTACH_DATA_VALUE () { 3 }
sub XRT_AXIS_X () { 0 }
sub XRT_AXIS_Y () { 1 }
sub XRT_AXIS_Y2 () { 2 }
sub XRT_BORDER_NONE () { 0 }
sub XRT_BORDER_3D_OUT () { 1 }
sub XRT_BORDER_3D_IN () { 2 }
sub XRT_BORDER_SHADOW () { 3 }
sub XRT_BORDER_PLAIN () { 4 }
sub XRT_BORDER_ETCHED_IN () { 5 }
sub XRT_BORDER_ETCHED_OUT () { 6 }
sub XRT_BORDER_FRAME_IN () { 7 }
sub XRT_BORDER_FRAME_OUT () { 8 }
sub XRT_BORDER_BEVEL () { 9 }
sub XRT_DATA_ARRAY () { 1 }
sub XRT_DATA_GENERAL () { 2 }
sub XRT_DISPLAY_SHOW () { 1 }
sub XRT_DISPLAY_HIDE () { 2 }
sub XRT_DISPLAY_EXCLUDE () { 3 }
sub XRT_FPAT_NONE () { 1 }
sub XRT_FPAT_SOLID () { 2 }
sub XRT_FPAT_25_PERCENT () { 3 }
sub XRT_FPAT_50_PERCENT () { 4 }
sub XRT_FPAT_75_PERCENT () { 5 }
sub XRT_FPAT_HORIZ_STRIPE () { 6 }
sub XRT_FPAT_VERT_STRIPE () { 7 }
sub XRT_FPAT_45_STRIPE () { 8 }
sub XRT_FPAT_135_STRIPE () { 9 }
sub XRT_FPAT_DIAG_HATCHED () { 10 }
sub XRT_FPAT_CROSS_HATCHED () { 11 }
sub XRT_LPAT_NONE () { 1 }
sub XRT_LPAT_SOLID () { 2 }
sub XRT_LPAT_LONG_DASH () { 3 }
sub XRT_LPAT_DOTTED () { 4 }
sub XRT_LPAT_SHORT_DASH () { 5 }
sub XRT_LPAT_LSL_DASH () { 6 }
sub XRT_LPAT_DASH_DOT () { 7 }
sub XRT_MARKER_SET_POINT () { 1 }
sub XRT_MARKER_VALUE () { 2 }
sub XRT_NUM_PRECISION () { 0 }
sub XRT_NUM_ROUND () { 1 }
sub XRT_ORIGIN_AUTO () { 0 }
sub XRT_ORIGIN_ZERO () { 1 }
sub XRT_ORIGIN_MIN () { 2 }
sub XRT_ORIGIN_MAX () { 3 }
sub XRT_PIEORDER_ASCENDING () { 1 }
sub XRT_PIEORDER_DESCENDING () { 2 }
sub XRT_PIEORDER_DATA_ORDER () { 3 }
sub XRT_PIE_SLICE_CUTOFF () { 1 }
sub XRT_PIE_PERCENTILE () { 2 }
sub XRT_POINT_NONE () { 1 }
sub XRT_POINT_DOT () { 2 }
sub XRT_POINT_BOX () { 3 }
sub XRT_POINT_TRI () { 4 }
sub XRT_POINT_DIAMOND () { 5 }
sub XRT_POINT_STAR () { 6 }
sub XRT_POINT_VERT_LINE () { 7 }
sub XRT_POINT_HORIZ_LINE () { 8 }
sub XRT_POINT_CROSS () { 9 }
sub XRT_POINT_CIRCLE () { 10 }
sub XRT_POINT_SQUARE () { 11 }
sub XRT_REASON_MODIFY_START () { 500 }
sub XRT_REASON_MODIFY_END () { 501 }
sub XRT_REASON_ROTATE () { 502 }
sub XRT_REASON_TRANSFORM () { 503 }
sub XRT_REASON_ZOOM_AXIS () { 504 }
sub XRT_REASON_MAP () { 505 }
sub XRT_REASON_PICK () { 506 }
sub XRT_RGN_IN_GRAPH () { -100 }
sub XRT_RGN_IN_LEGEND () { -99 }
sub XRT_RGN_IN_HEADER () { -98 }
sub XRT_RGN_IN_FOOTER () { -97 }
sub XRT_RGN_NOWHERE () { -96 }
sub XRT_ROTATE_NONE () { 1 }
sub XRT_ROTATE_90 () { 2 }
sub XRT_ROTATE_270 () { 3 }
sub XRT_SHADING_COLOR () { 1 }
sub XRT_SHADING_DITHERED () { 2 }
sub XRT_SHADING_NONE () { 3 }
sub XRT_TMUNIT_SECONDS () { 1 }
sub XRT_TMUNIT_MINUTES () { 2 }
sub XRT_TMUNIT_HOURS () { 3 }
sub XRT_TMUNIT_DAYS () { 4 }
sub XRT_TMUNIT_WEEKS () { 5 }
sub XRT_TMUNIT_MONTHS () { 6 }
sub XRT_TMUNIT_YEARS () { 7 }
sub XRT_TYPE_PLOT () { 1 }
sub XRT_TYPE_BAR () { 2 }
sub XRT_TYPE_PIE () { 3 }
sub XRT_TYPE_STACKING_BAR () { 4 }
sub XRT_TYPE_AREA () { 5 }
sub XRT_TYPE_HILO () { 6 }
sub XRT_TYPE_HILO_OPEN_CLOSE () { 7 }
sub XRT_TYPE_CANDLE () { 8 }
sub XRT_TYPE_POLAR () { 9 }
sub XRT_TYPE_RADAR () { 10 }
sub XRT_TYPE_FILLED_RADAR () { 11 }
sub XRT_XMETHOD_XVALUES () { 0 }
sub XRT_XMETHOD_POINT_LABELS () { 1 }
sub XRT_XMETHOD_XLABELS () { 2 }
sub XRT_XMETHOD_TIME_LABELS () { 3 }
sub XRTGEAR_COLUMN_RESIZE_ALL () { 0 }
sub XRTGEAR_COLUMN_RESIZE_LABELS_ONLY () { 1 }
sub XRTGEAR_COLUMN_RESIZE_NONE () { 2 }
sub XRTGEAR_GLABEL_LAYOUT_SPACING_DEFAULT () { 2 }
sub XRTGEAR_LINESTYLE_NONE () { 0 }
sub XRTGEAR_LINESTYLE_DOTTED () { 1 }
sub XRTGEAR_LINESTYLE_SOLID () { 2 }
sub XRTGEAR_FOLDERSTATE_INVALID () { 0 }
sub XRTGEAR_FOLDERSTATE_CLOSED () { 1 }
sub XRTGEAR_FOLDERSTATE_OPEN_FOLDERS () { 2 }
sub XRTGEAR_FOLDERSTATE_OPEN_ITEMS () { 4 }
sub XRTGEAR_FOLDERSTATE_OPEN_ALL () { 8 }
sub XRTGEAR_BORDER_LOC_LABELS () { 0 }
sub XRTGEAR_BORDER_LOC_NODES () { 1 }
sub XRTGEAR_BORDER_LOC_LABELS_SEPARATED_FROM_NODES () { 2 }
sub XRTGEAR_BORDER_LOC_EACH_LABEL_SEPARATED_FROM_NODES () { 3 }
sub XRTGEAR_BORDER_LOC_EACH_LABEL () { 4 }
sub XRTGEAR_BORDER_LOC_LABELS_AND_NODES () { 5 }
sub XRTGEAR_REASON_ACTIVATE () { 200 }
sub XRTGEAR_REASON_COLUMN_MOVE_BEGIN () { 201 }
sub XRTGEAR_REASON_COLUMN_MOVE_END () { 202 }
sub XRTGEAR_REASON_COLUMN_SELECT_BEGIN () { 203 }
sub XRTGEAR_REASON_COLUMN_SELECT_END () { 204 }
sub XRTGEAR_REASON_CURSOR_EDGE_LEFT () { 205 }
sub XRTGEAR_REASON_CURSOR_EDGE_RIGHT () { 206 }
sub XRTGEAR_REASON_CURSOR_INSIDE () { 207 }
sub XRTGEAR_REASON_CURSOR_LEAVE () { 208 }
sub XRTGEAR_REASON_DISPLAY_BEGIN () { 209 }
sub XRTGEAR_REASON_DISPLAY_END () { 210 }
sub XRTGEAR_REASON_EXPORT_DRAG_BEGIN () { 211 }
sub XRTGEAR_REASON_EXPORT () { 212 }
sub XRTGEAR_REASON_EXPORT_DRAG_END () { 213 }
sub XRTGEAR_REASON_EXPOSE_BEGIN () { 214 }
sub XRTGEAR_REASON_EXPOSE_END () { 215 }
sub XRTGEAR_REASON_FOCUS_IN_BEGIN () { 216 }
sub XRTGEAR_REASON_FOCUS_IN_END () { 217 }
sub XRTGEAR_REASON_FOCUS_OUT () { 218 }
sub XRTGEAR_REASON_FOLDER_CHANGE_BEGIN () { 219 }
sub XRTGEAR_REASON_FOLDER_CHANGE_END () { 220 }
sub XRTGEAR_REASON_FORMAT_LABEL_BEGIN () { 221 }
sub XRTGEAR_REASON_FORMAT_LABEL_END () { 222 }
sub XRTGEAR_REASON_IMPORT_DRAG_MOTION () { 223 }
sub XRTGEAR_REASON_IMPORT_BEGIN () { 224 }
sub XRTGEAR_REASON_IMPORT_END () { 225 }
sub XRTGEAR_REASON_LIST_ADD () { 226 }
sub XRTGEAR_REASON_LIST_DELETED () { 227 }
sub XRTGEAR_REASON_LIST_MOVE () { 228 }
sub XRTGEAR_REASON_LIST_PENDING_DELETE () { 229 }
sub XRTGEAR_REASON_LIST_SET () { 230 }
sub XRTGEAR_REASON_MENU_BEGIN () { 231 }
sub XRTGEAR_REASON_MENU_END () { 232 }
sub XRTGEAR_REASON_NODE_CHANGE_BEGIN () { 233 }
sub XRTGEAR_REASON_NODE_CHANGE_END () { 234 }
sub XRTGEAR_REASON_NODE_CREATE_BEGIN () { 235 }
sub XRTGEAR_REASON_NODE_CREATE_END () { 236 }
sub XRTGEAR_REASON_NODE_MOVE_BEGIN () { 237 }
sub XRTGEAR_REASON_NODE_MOVE_END () { 238 }
sub XRTGEAR_REASON_PAGE_BEGIN () { 239 }
sub XRTGEAR_REASON_PAGE_END () { 240 }
sub XRTGEAR_REASON_PAGE_PRINT_BEGIN () { 241 }
sub XRTGEAR_REASON_PAGE_PRINT_END () { 242 }
sub XRTGEAR_REASON_PROGRESS () { 243 }
sub XRTGEAR_REASON_PROGRESS_BEGIN () { 244 }
sub XRTGEAR_REASON_PROGRESS_COMPLETE () { 245 }
sub XRTGEAR_REASON_RESIZE_BEGIN () { 246 }
sub XRTGEAR_REASON_RESIZE_END () { 247 }
sub XRTGEAR_REASON_SELECT_BEGIN () { 248 }
sub XRTGEAR_REASON_SELECT_END () { 249 }
sub XRTGEAR_REASON_STATE_BEGIN () { 250 }
sub XRTGEAR_REASON_STATE_END () { 251 }
sub XRTGEAR_REASON_UNSELECT_BEGIN () { 252 }
sub XRTGEAR_REASON_UNSELECT_END () { 253 }
sub XRTGEAR_REASON_RESIZE () { 247 }
sub XRTGEAR_TYPE_UNSPECIFIED () { 0 }
sub XRTGEAR_TYPE_STRING () { 1 }
sub XRTGEAR_TYPE_PIXMAP () { 2 }
sub XRTGEAR_TYPE_STRING_PIXMAP () { 3 }
sub XRTGEAR_ROTATE_NONE () { 0 }
sub XRTGEAR_ROTATE_90 () { 1 }
sub XRTGEAR_ROTATE_180 () { 2 }
sub XRTGEAR_ROTATE_270 () { 3 }
sub XRTGEAR_ROTATE_UNSPECIFIED () { 4 }
sub XRTGEAR_SIZE_PIXEL () { 0 }
sub XRTGEAR_SIZE_CHAR () { 1 }
sub XRTGEAR_SIZE_NODE () { 2 }
sub XRTGEAR_SIZE_COLUMN () { 3 }
sub XRTGEAR_SIZE_LABEL_VARIABLE () { 4 }
sub XRTGEAR_SIZE_VARIABLE () { 5 }
sub XRTGEAR_STRING_CENTER () { 0 }
sub XRTGEAR_STRING_TOP () { 1 }
sub XRTGEAR_STRING_LEFT () { 2 }
sub XRTGEAR_STRING_BOTTOM () { 3 }
sub XRTGEAR_STRING_RIGHT () { 4 }
sub XRTGEAR_ALIGN_BEGINNING () { 0 }
sub XRTGEAR_ALIGN_CENTER () { 1 }
sub XRTGEAR_ALIGN_END () { 2 }
sub XRTGEAR_ALIGNER_BEGINNING () { 0 }
sub XRTGEAR_ALIGNER_CENTER () { 1 }
sub XRTGEAR_ALIGNER_END () { 2 }
sub XRTGEAR_BORDER_NONE () { 0 }
sub XRTGEAR_BORDER_ETCHED_IN () { 1 }
sub XRTGEAR_BORDER_ETCHED_OUT () { 2 }
sub XRTGEAR_BORDER_IN () { 3 }
sub XRTGEAR_BORDER_OUT () { 4 }
sub XRTGEAR_BORDER_FRAME_IN () { 5 }
sub XRTGEAR_BORDER_FRAME_OUT () { 6 }
sub XRTGEAR_BORDER_BEVEL () { 7 }
sub XRTGEAR_BORDER_PLAIN () { 8 }
sub XRTGEAR_BORDER_SHADOW () { 9 }
sub XRTGEAR_DISPLAY_AS_NEEDED () { 0 }
sub XRTGEAR_DISPLAY_ALWAYS () { 1 }
sub XRTGEAR_DISPLAY_NEVER () { 2 }
sub XRTGEAR_RESTRICT_NOTHING () { 0 }
sub XRTGEAR_RESTRICT_ITEMS () { 1 }
sub XRTGEAR_RESTRICT_FOLDERS () { 2 }
sub XRTGEAR_RESTRICT_MULTI_LEVEL () { 4 }
sub XRTGEAR_RESTRICT_ALL () { 7 }
sub XRTGEAR_TRUNCATE () { 0 }
sub XRTGEAR_TRUNCATE_WITH_ARROW () { 1 }
sub XRTGEAR_COMPRESS_WITH_ELLIPSIS () { 2 }
sub XRTGEAR_IMPORT_NOTHING () { 0 }
sub XRTGEAR_IMPORT_ANYTHING () { 1 }
sub XRTGEAR_IMPORT_WITHIN_APP () { 2 }
sub XRTGEAR_IMPORT_WITHIN_WIDGET () { 3 }
sub XRTGEAR_INDENT_PIXEL () { 0 }
sub XRTGEAR_INDENT_CHAR () { 1 }
sub XRTGEAR_INDENT_NONE () { 2 }
sub XRTGEAR_LOCATION_ON_NODE () { 0 }
sub XRTGEAR_LOCATION_ON_SHORTCUT () { 1 }
sub XRTGEAR_LOCATION_ON_LABEL () { 2 }
sub XRTGEAR_LOCATION_NOWHERE () { 3 }
sub XRTGEAR_MOVE_NOWHERE () { 0 }
sub XRTGEAR_MOVE_WITHIN_LEVEL () { 1 }
sub XRTGEAR_MOVE_WITHIN_WIDGET () { 2 }
sub XRTGEAR_MOVE_WITHIN_APP () { 3 }
sub XRTGEAR_SELECTION_POLICY_NONE () { 0 }
sub XRTGEAR_SELECTION_POLICY_SINGLE () { 1 }
sub XRTGEAR_SELECTION_POLICY_SINGLE_AUTO_SELECT () { 2 }
sub XRTGEAR_SELECTION_POLICY_RANGE () { 3 }
sub XRTGEAR_SELECTION_POLICY_MULTIPLE () { 4 }
sub XRTGEAR_SELECTION_POLICY_MULTIPLE_AUTO_UNSELECT () { 5 }
sub XRTGEAR_WIDGET_RESIZE_VARIABLE () { 0 }
sub XRTGEAR_WIDGET_RESIZE_GROW_ONLY () { 1 }
sub XRTGEAR_WIDGET_RESIZE_FIXED () { 2 }
sub XRTGEAR_ARROW_NONE () { 0 }
sub XRTGEAR_ARROW_WEDGE () { 1 }
sub XRTGEAR_ARROW_WITH_UNDERBAR () { 2 }
sub XRTGEAR_ARROW_CUSTOM () { 3 }
sub XRTGEAR_MENU_ALIGN_BEGINNING () { 0 }
sub XRTGEAR_MENU_ALIGN_BOTH () { 1 }
sub XRTGEAR_MENU_ALIGN_END () { 2 }
sub XRTGEAR_ATTACH_ALWAYS () { 0 }
sub XRTGEAR_ATTACH_NONE () { 1 }
sub XRTGEAR_STATE_OFF () { 0 }
sub XRTGEAR_STATE_ON () { 1 }
sub XRTGEAR_STATE_INDETERMINATE () { 2 }
sub XRTGEAR_PAGE_FIRST () { -1 }
sub XRTGEAR_PAGE_LAST () { -2 }
sub XRTGEAR_NOTFOUND () { -999 }
sub XRTGEAR_NOVALUE () { -999 }
sub XRTGEAR_PS_ALL () { 1 }
sub XRTGEAR_PS_BORDER_TYPE () { 2 }
sub XRTGEAR_PS_CM () { 3 }
sub XRTGEAR_PS_COLOR () { 4 }
sub XRTGEAR_PS_COLUMN_PAGE_BREAK_LIST () { 5 }
sub XRTGEAR_PS_EDGE_PAGES () { 6 }
sub XRTGEAR_PS_FOOTER () { 7 }
sub XRTGEAR_PS_FOOTER_FONT () { 8 }
sub XRTGEAR_PS_FOOTER_MARGIN () { 9 }
sub XRTGEAR_PS_FOOTER_POINT_SIZE () { 10 }
sub XRTGEAR_PS_HEADER () { 11 }
sub XRTGEAR_PS_HEADER_FONT () { 12 }
sub XRTGEAR_PS_HEADER_MARGIN () { 13 }
sub XRTGEAR_PS_HEADER_POINT_SIZE () { 14 }
sub XRTGEAR_PS_INCHES () { 15 }
sub XRTGEAR_PS_LANDSCAPE () { 16 }
sub XRTGEAR_PS_MARGIN_BOTTOM () { 17 }
sub XRTGEAR_PS_MARGIN_LEFT () { 18 }
sub XRTGEAR_PS_MARGIN_RIGHT () { 19 }
sub XRTGEAR_PS_MARGIN_TOP () { 20 }
sub XRTGEAR_PS_MONO () { 21 }
sub XRTGEAR_PS_NODE_PAGE_BREAK_LIST () { 22 }
sub XRTGEAR_PS_NONE () { 23 }
sub XRTGEAR_PS_NUM_COPIES () { 24 }
sub XRTGEAR_PS_ORIENTATION () { 25 }
sub XRTGEAR_PS_PAPERSIZE_HEIGHT () { 26 }
sub XRTGEAR_PS_PAPERSIZE_WIDTH () { 27 }
sub XRTGEAR_PS_PORTRAIT () { 28 }
sub XRTGEAR_PS_SCALE () { 29 }
sub XRTGEAR_PS_SHOWPAGE () { 30 }
sub XRTGEAR_PS_SHOW_COLUMN_LABELS () { 31 }
sub XRTGEAR_PS_SHOW_START_NODE () { 32 }
sub XRTGEAR_PS_START_NODE () { 33 }
sub XRTGEAR_PS_UNITS () { 34 }
sub XRTGEAR_PS_FIT_TO_PAGE () { 0 }
sub XRTGEAR_PS_FIT_TO_PAGE_WIDTH () { -1074790400 }
sub XRTGEAR_PS_FIT_TO_PAGE_HEIGHT () { -1073741824 }
sub XRTGEAR_SEARCH_SINGLE () { 0 }
sub XRTGEAR_SEARCH_MULTICHAR () { 1 }
sub XRTGEAR_LIST_INVALID_POSITION () { -1 }
sub XRTGEAR_LIST_ITEM_NOT_FOUND () { -2 }
sub XRTGEAR_DIRECTION_FORWARD () { 0 }
sub XRTGEAR_DIRECTION_BACKWARD () { 1 }
sub XRTGEAR_PROGRESS_BAR () { 0 }
sub XRTGEAR_PROGRESS_DISCRETE_BAR () { 1 }
sub XRTGEAR_PROGRESS_ICON () { 2 }
sub XRTGEAR_PROGRESS_STACKING_ICONS () { 3 }
sub XRTGEAR_PUSHB_LAYOUT_SPACING_DEFAULT () { 2 }
sub XRTGEAR_SNAP_ALL () { 1 }
sub XRTGEAR_SNAP_AS_IS () { 2 }
sub XRTGEAR_SNAP_AUTO () { 3 }
sub XRTGEAR_SNAP_BEST () { 4 }
sub XRTGEAR_SNAP_CM () { 5 }
sub XRTGEAR_SNAP_COLOR () { 6 }
sub XRTGEAR_SNAP_INCHES () { 7 }
sub XRTGEAR_SNAP_LANDSCAPE () { 8 }
sub XRTGEAR_SNAP_MARGIN_BOTTOM () { 9 }
sub XRTGEAR_SNAP_MARGIN_LEFT () { 10 }
sub XRTGEAR_SNAP_MARGIN_RIGHT () { 11 }
sub XRTGEAR_SNAP_MARGIN_TOP () { 12 }
sub XRTGEAR_SNAP_MONO () { 13 }
sub XRTGEAR_SNAP_NONE () { 14 }
sub XRTGEAR_SNAP_ORIENTATION () { 15 }
sub XRTGEAR_SNAP_PAPERSIZE_HEIGHT () { 16 }
sub XRTGEAR_SNAP_PAPERSIZE_WIDTH () { 17 }
sub XRTGEAR_SNAP_PORTRAIT () { 18 }
sub XRTGEAR_SNAP_SCALE () { 19 }
sub XRTGEAR_SNAP_SHOWPAGE () { 20 }
sub XRTGEAR_SNAP_UNITS () { 21 }
sub XRTGEAR_SNAP_NUM_COPIES () { 22 }
sub XRTGEAR_ANCHOR_SIDE_LEFT () { 0 }
sub XRTGEAR_ANCHOR_SIDE_RIGHT () { 1 }
sub XRTGEAR_ANCHOR_SIDE_TOP () { 2 }
sub XRTGEAR_ANCHOR_SIDE_BOTTOM () { 3 }
sub XRTGEAR_STYLE_ROUNDED () { 0 }
sub XRTGEAR_STYLE_SQUARE () { 1 }
sub XRTGEAR_STYLE_SLANTED () { 2 }
sub XRTGEAR_STYLE_CHAMFERED () { 3 }
sub XRTGEAR_LAYOUT_SPACING_DEFAULT () { 2 }
sub XRTGEAR_ACTION_TAB () { 0 }
sub XRTGEAR_ACTION_SCROLL_INCR () { 1 }
sub XRTGEAR_ACTION_SCROLL_DECR () { 2 }
sub XRTGEAR_ACTION_SET_VALUES () { 3 }
sub XRTGEAR_ACTION_OTHERS () { 4 }
sub XRTGEAR_CHILD_TYPE_PAGE () { 0 }
sub XRTGEAR_CHILD_TYPE_TAB () { 1 }
sub XRTGEAR_CHILD_TYPE_INTERNAL () { 2 }
sub XRTGEAR_SIDE_LEFT () { 0 }
sub XRTGEAR_SIDE_RIGHT () { 1 }
sub XRTGEAR_SIDE_TOP () { 2 }
sub XRTGEAR_SIDE_BOTTOM () { 3 }
sub XRTGEAR_RESIZE_NONE () { 0 }
sub XRTGEAR_RESIZE_HORIZONTAL () { 1 }
sub XRTGEAR_RESIZE_VERTICAL () { 2 }
sub XRTGEAR_RESIZE_ALL () { 3 }
sub XRTGEAR_POSITION_TOP_LEFT () { 0 }
sub XRTGEAR_POSITION_TOP_RIGHT () { 1 }
sub XRTGEAR_POSITION_TOP_CENTER () { 2 }
sub XRTGEAR_POSITION_MIDDLE_LEFT () { 3 }
sub XRTGEAR_POSITION_MIDDLE_RIGHT () { 4 }
sub XRTGEAR_POSITION_MIDDLE_CENTER () { 5 }
sub XRTGEAR_POSITION_BOTTOM_LEFT () { 6 }
sub XRTGEAR_POSITION_BOTTOM_RIGHT () { 7 }
sub XRTGEAR_POSITION_BOTTOM_CENTER () { 8 }
sub XRTGEAR_OVERLAP_AS_NEEDED () { 8191 }
sub XRTGEAR_UNSPECIFIED_PAGE_NUMBER () { 2147483647 }
sub XRTGEAR_UNSPECIFIED_LAST_TAB () { 2147483647 }
sub XRTGEAR_UNSPECIFIED_FIRST_TAB () { 2147483647 }
sub XRTGEAR_UNSPECIFIED_ACTIVE_PAGE_NUMBER () { -1 }
sub XRTGEAR_UNSPECIFIED_PAGE_POSITION () { -1 }
sub XRTGEAR_PAGE_NO_VALUE () { -1 }
sub XRTGEAR_PARENT () { -1 }
sub XRTGEAR_SELF () { -2 }
sub XRTGEAR_INDICATOR_NONE () { 0 }
sub XRTGEAR_INDICATOR_FILL () { 1 }
sub XRTGEAR_INDICATOR_CHECK () { 2 }
sub XRTGEAR_INDICATOR_CHECK_BOX () { 3 }
sub XRTGEAR_INDICATOR_CIRCLE () { 4 }
sub XRTGEAR_INDICATOR_CIRCLE_BOX () { 5 }
sub XRTGEAR_INDICATOR_CROSS () { 6 }
sub XRTGEAR_INDICATOR_CROSS_BOX () { 7 }
sub XRTGEAR_INDICATOR_PIXMAP () { 8 }
sub XRT_RELEASE_STRING () { '3.0.0' }
sub XRTGEAR_RELEASE_STRING () { '2.0.1' }
sub XRTGEAR_TGT_NODE () { 'XRTGEAR_TARGET_NODE' }
sub XRTGEAR_TGT_SELECTION () { 'XRTGEAR_TARGET_SELECTION' }
sub XRTGEAR_TGT_COLUMN () { 'XRTGEAR_TARGET_COLUMN' }
sub XRTGEAR_TGT_COMPOUND_TEXT () { 'COMPOUND_TEXT' }
sub XRTGEAR_TGT_TEXT () { 'TEXT' }
sub XRTGEAR_TGT_STRING () { 'STRING' }
sub XRTGEAR_NODE_STYLE_DEFAULT () { 'DefaultStyle' }
sub XmNxrtComboArrow () { 'xrtComboArrow' }
sub XmNxrtComboArrowClass () { 'xrtComboArrowClass' }
sub XmNxrtComboArrowType () { 'xrtComboArrowType' }
sub XmNxrtComboField () { 'xrtComboField' }
sub XmNxrtComboFieldClass () { 'xrtComboFieldClass' }
sub XmNxrtComboFieldType () { 'xrtComboFieldType' }
sub XmNxrtComboSpacing () { 'xrtComboSpacing' }
sub XmNxrtFldAllowNull () { 'xrtFldAllowNull' }
sub XmNxrtFldCase () { 'xrtFldCase' }
sub XmNxrtFldCompleteCallback () { 'xrtFldCompleteCallback' }
sub XmNxrtFldConvertCallback () { 'xrtFldConvertCallback' }
sub XmNxrtFldCounterIncrement () { 'xrtFldCounterIncrement' }
sub XmNxrtFldDecimalPlaces () { 'xrtFldDecimalPlaces' }
sub XmNxrtFldDefaultBackground () { 'xrtFldDefaultBackground' }
sub XmNxrtFldDefaultForeground () { 'xrtFldDefaultForeground' }
sub XmNxrtFldDefaultValue () { 'xrtFldDefaultValue' }
sub XmNxrtFldDisplayFormat () { 'xrtFldDisplayFormat' }
sub XmNxrtFldDisplayFormatString () { 'xrtFldDisplayFormatString' }
sub XmNxrtFldDisplayHorizScrollBar () { 'xrtFldDisplayHorizScrollBar' }
sub XmNxrtFldDisplayVertScrollBar () { 'xrtFldDisplayVertScrollBar' }
sub XmNxrtFldEditFormat () { 'xrtFldEditFormat' }
sub XmNxrtFldEnterCallback () { 'xrtFldEnterCallback' }
sub XmNxrtFldEnterFormatList () { 'xrtFldEnterFormatList' }
sub XmNxrtFldErrorBackground () { 'xrtFldErrorBackground' }
sub XmNxrtFldErrorCallback () { 'xrtFldErrorCallback' }
sub XmNxrtFldErrorForeground () { 'xrtFldErrorForeground' }
sub XmNxrtFldErrorString () { 'xrtFldErrorString' }
sub XmNxrtFldExitCallback () { 'xrtFldExitCallback' }
sub XmNxrtFldFieldType () { 'xrtFldFieldType' }
sub XmNxrtFldInternalValue () { 'xrtFldInternalValue' }
sub XmNxrtFldInternalValueLong () { 'xrtFldInternalValueLong' }
sub XmNxrtFldInvalidChars () { 'xrtFldInvalidChars' }
sub XmNxrtFldIsDefault () { 'xrtFldIsDefault' }
sub XmNxrtFldIsModified () { 'xrtFldIsModified' }
sub XmNxrtFldIsValid () { 'xrtFldIsValid' }
sub XmNxrtFldLastError () { 'xrtFldLastError' }
sub XmNxrtFldLeadingZero () { 'xrtFldLeadingZero' }
sub XmNxrtFldMask () { 'xrtFldMask' }
sub XmNxrtFldMaskChars () { 'xrtFldMaskChars' }
sub XmNxrtFldMatchMask () { 'xrtFldMatchMask' }
sub XmNxrtFldMatchPickList () { 'xrtFldMatchPickList' }
sub XmNxrtFldMax () { 'xrtFldMax' }
sub XmNxrtFldMaxLineLength () { 'xrtFldMaxLineLength' }
sub XmNxrtFldMaxLines () { 'xrtFldMaxLines' }
sub XmNxrtFldMenuAlignment () { 'xrtFldMenuAlignment' }
sub XmNxrtFldMenuCallback () { 'xrtFldMenuCallback' }
sub XmNxrtFldMenuList () { 'xrtFldMenuList' }
sub XmNxrtFldMilleniumThreshold () { 'xrtFldMilleniumThreshold' }
sub XmNxrtFldMin () { 'xrtFldMin' }
sub XmNxrtFldNegativeFormat () { 'xrtFldNegativeFormat' }
sub XmNxrtFldOverstrike () { 'xrtFldOverstrike' }
sub XmNxrtFldPickList () { 'xrtFldPickList' }
sub XmNxrtFldPickListIndex () { 'xrtFldPickListIndex' }
sub XmNxrtFldPromptString () { 'xrtFldPromptString' }
sub XmNxrtFldRange () { 'xrtFldRange' }
sub XmNxrtFldSearchPolicy () { 'xrtFldSearchPolicy' }
sub XmNxrtFldSpinCallback () { 'xrtFldSpinCallback' }
sub XmNxrtFldValidChars () { 'xrtFldValidChars' }
sub XmNxrtFldValidateCallback () { 'xrtFldValidateCallback' }
sub XmNxrtFldVisibleItemCount () { 'xrtFldVisibleItemCount' }
sub XmNxrtGearActivateCallback () { 'xrtGearActivateCallback' }
sub XmNxrtGearActivePageNumber () { 'xrtGearActivePageNumber' }
sub XmNxrtGearActivePageWidget () { 'xrtGearActivePageWidget' }
sub XmNxrtGearActiveTabWidget () { 'xrtGearActiveTabWidget' }
sub XmNxrtGearAlignBaseline () { 'xrtGearAlignBaseline' }
sub XmNxrtGearAlignerAlignment () { 'xrtGearAlignerAlignment' }
sub XmNxrtGearAlignment () { 'xrtGearAlignment' }
sub XmNxrtGearAllowResize () { 'xrtGearAllowResize' }
sub XmNxrtGearAnchorSide () { 'xrtGearAnchorSide' }
sub XmNxrtGearArmMask () { 'xrtGearArmMask' }
sub XmNxrtGearArmPixmap () { 'xrtGearArmPixmap' }
sub XmNxrtGearArrow () { 'xrtGearArrow' }
sub XmNxrtGearArrowClass () { 'xrtGearArrowClass' }
sub XmNxrtGearArrowDirection () { 'xrtGearArrowDirection' }
sub XmNxrtGearArrowDisplayPolicy () { 'xrtGearArrowDisplayPolicy' }
sub XmNxrtGearArrowHeight () { 'xrtGearArrowHeight' }
sub XmNxrtGearArrowType () { 'xrtGearArrowType' }
sub XmNxrtGearArrowWidth () { 'xrtGearArrowWidth' }
sub XmNxrtGearAutoSort () { 'xrtGearAutoSort' }
sub XmNxrtGearBackground () { 'xrtGearBackground' }
sub XmNxrtGearBackgroundSelected () { 'xrtGearBackgroundSelected' }
sub XmNxrtGearBarColor () { 'xrtGearBarColor' }
sub XmNxrtGearBarCount () { 'xrtGearBarCount' }
sub XmNxrtGearBarSpacing () { 'xrtGearBarSpacing' }
sub XmNxrtGearBorderColor () { 'xrtGearBorderColor' }
sub XmNxrtGearBorderLocation () { 'xrtGearBorderLocation' }
sub XmNxrtGearBorderType () { 'xrtGearBorderType' }
sub XmNxrtGearBottomSpace () { 'xrtGearBottomSpace' }
sub XmNxrtGearChildType () { 'xrtGearChildType' }
sub XmNxrtGearColumnLabelsShow () { 'xrtGearColumnLabelsShow' }
sub XmNxrtGearColumnLabelsSpacing () { 'xrtGearColumnLabelsSpacing' }
sub XmNxrtGearColumnList () { 'xrtGearColumnList' }
sub XmNxrtGearColumnMoveAllow () { 'xrtGearColumnMoveAllow' }
sub XmNxrtGearColumnMoveCallback () { 'xrtGearColumnMoveCallback' }
sub XmNxrtGearColumnOrderList () { 'xrtGearColumnOrderList' }
sub XmNxrtGearColumnPreferredVisibleCount () { 'xrtGearColumnPreferredVisibleCount' }
sub XmNxrtGearColumnSelected () { 'xrtGearColumnSelected' }
sub XmNxrtGearColumnSelectionCallback () { 'xrtGearColumnSelectionCallback' }
sub XmNxrtGearColumnSpacing () { 'xrtGearColumnSpacing' }
sub XmNxrtGearCornerPercent () { 'xrtGearCornerPercent' }
sub XmNxrtGearCornerSize () { 'xrtGearCornerSize' }
sub XmNxrtGearCursor () { 'xrtGearCursor' }
sub XmNxrtGearCursorResizeWidth () { 'xrtGearCursorResizeWidth' }
sub XmNxrtGearCursorTracking () { 'xrtGearCursorTracking' }
sub XmNxrtGearCursorTrackingCallback () { 'xrtGearCursorTrackingCallback' }
sub XmNxrtGearDebug () { 'xrtGearDebug' }
sub XmNxrtGearDelay () { 'xrtGearDelay' }
sub XmNxrtGearDisplayCallback () { 'xrtGearDisplayCallback' }
sub XmNxrtGearDoubleBuffer () { 'xrtGearDoubleBuffer' }
sub XmNxrtGearFirstVisibleTab () { 'xrtGearFirstVisibleTab' }
sub XmNxrtGearFolderState () { 'xrtGearFolderState' }
sub XmNxrtGearFolderStateCallback () { 'xrtGearFolderStateCallback' }
sub XmNxrtGearFolderStateMask () { 'xrtGearFolderStateMask' }
sub XmNxrtGearFolderStates () { 'xrtGearFolderStates' }
sub XmNxrtGearFontList () { 'xrtGearFontList' }
sub XmNxrtGearFontListSelected () { 'xrtGearFontListSelected' }
sub XmNxrtGearForeground () { 'xrtGearForeground' }
sub XmNxrtGearForegroundSelected () { 'xrtGearForegroundSelected' }
sub XmNxrtGearGroup () { 'xrtGearGroup' }
sub XmNxrtGearHeightPreferredCount () { 'xrtGearHeightPreferredCount' }
sub XmNxrtGearHeightResizePolicy () { 'xrtGearHeightResizePolicy' }
sub XmNxrtGearHeightSizingPolicy () { 'xrtGearHeightSizingPolicy' }
sub XmNxrtGearHeightVirtual () { 'xrtGearHeightVirtual' }
sub XmNxrtGearHighlightThickness () { 'xrtGearHighlightThickness' }
sub XmNxrtGearIcon () { 'xrtGearIcon' }
sub XmNxrtGearIconClosed () { 'xrtGearIconClosed' }
sub XmNxrtGearIconClosedSelected () { 'xrtGearIconClosedSelected' }
sub XmNxrtGearIconItem () { 'xrtGearIconItem' }
sub XmNxrtGearIconItemSelected () { 'xrtGearIconItemSelected' }
sub XmNxrtGearIconOpen () { 'xrtGearIconOpen' }
sub XmNxrtGearIconOpenSelected () { 'xrtGearIconOpenSelected' }
sub XmNxrtGearImportCallback () { 'xrtGearImportCallback' }
sub XmNxrtGearIndicator () { 'xrtGearIndicator' }
sub XmNxrtGearIndicatorMaskList () { 'xrtGearIndicatorMaskList' }
sub XmNxrtGearIndicatorPixmapList () { 'xrtGearIndicatorPixmapList' }
sub XmNxrtGearInsensitiveStyle () { 'xrtGearInsensitiveStyle' }
sub XmNxrtGearLabel () { 'xrtGearLabel' }
sub XmNxrtGearLabelAlignment () { 'xrtGearLabelAlignment' }
sub XmNxrtGearLabelFormat () { 'xrtGearLabelFormat' }
sub XmNxrtGearLabelFormatCallback () { 'xrtGearLabelFormatCallback' }
sub XmNxrtGearLabelPixmap () { 'xrtGearLabelPixmap' }
sub XmNxrtGearLabelShow () { 'xrtGearLabelShow' }
sub XmNxrtGearLabelType () { 'xrtGearLabelType' }
sub XmNxrtGearLastVisibleTab () { 'xrtGearLastVisibleTab' }
sub XmNxrtGearLayoutSpacing () { 'xrtGearLayoutSpacing' }
sub XmNxrtGearLeftSpace () { 'xrtGearLeftSpace' }
sub XmNxrtGearLineColor () { 'xrtGearLineColor' }
sub XmNxrtGearLineStyle () { 'xrtGearLineStyle' }
sub XmNxrtGearLineWidth () { 'xrtGearLineWidth' }
sub XmNxrtGearMarginHeight () { 'xrtGearMarginHeight' }
sub XmNxrtGearMarginLeft () { 'xrtGearMarginLeft' }
sub XmNxrtGearMarginRight () { 'xrtGearMarginRight' }
sub XmNxrtGearMarginWidth () { 'xrtGearMarginWidth' }
sub XmNxrtGearMask () { 'xrtGearMask' }
sub XmNxrtGearMenuCallback () { 'xrtGearMenuCallback' }
sub XmNxrtGearMenuList () { 'xrtGearMenuList' }
sub XmNxrtGearNodeAlignment () { 'xrtGearNodeAlignment' }
sub XmNxrtGearNodeChildList () { 'xrtGearNodeChildList' }
sub XmNxrtGearNodeCompareProc () { 'xrtGearNodeCompareProc' }
sub XmNxrtGearNodeCreateCallback () { 'xrtGearNodeCreateCallback' }
sub XmNxrtGearNodeCurrent () { 'xrtGearNodeCurrent' }
sub XmNxrtGearNodeCurrentChangedCallback () { 'xrtGearNodeCurrentChangedCallback' }
sub XmNxrtGearNodeFolderData () { 'xrtGearNodeFolderData' }
sub XmNxrtGearNodeHeight () { 'xrtGearNodeHeight' }
sub XmNxrtGearNodeImportPolicy () { 'xrtGearNodeImportPolicy' }
sub XmNxrtGearNodeIndent () { 'xrtGearNodeIndent' }
sub XmNxrtGearNodeIndentPolicy () { 'xrtGearNodeIndentPolicy' }
sub XmNxrtGearNodeMovePolicy () { 'xrtGearNodeMovePolicy' }
sub XmNxrtGearNodeSpacing () { 'xrtGearNodeSpacing' }
sub XmNxrtGearNodeStyle () { 'xrtGearNodeStyle' }
sub XmNxrtGearNodeStyleDefault () { 'xrtGearNodeStyleDefault' }
sub XmNxrtGearNodeStyleList () { 'xrtGearNodeStyleList' }
sub XmNxrtGearNodeTop () { 'xrtGearNodeTop' }
sub XmNxrtGearNodeVisibleList () { 'xrtGearNodeVisibleList' }
sub XmNxrtGearNumStates () { 'xrtGearNumStates' }
sub XmNxrtGearOrientation () { 'xrtGearOrientation' }
sub XmNxrtGearOutlineBackground () { 'xrtGearOutlineBackground' }
sub XmNxrtGearPSFontMapList () { 'xrtGearPSFontMapList' }
sub XmNxrtGearPageAttachPolicy () { 'xrtGearPageAttachPolicy' }
sub XmNxrtGearPageCallback () { 'xrtGearPageCallback' }
sub XmNxrtGearPageNumber () { 'xrtGearPageNumber' }
sub XmNxrtGearPagePosition () { 'xrtGearPagePosition' }
sub XmNxrtGearPageWidget () { 'xrtGearPageWidget' }
sub XmNxrtGearPickList () { 'xrtGearPickList' }
sub XmNxrtGearPickListIndex () { 'xrtGearPickListIndex' }
sub XmNxrtGearPixmapRotation () { 'xrtGearPixmapRotation' }
sub XmNxrtGearPosition () { 'xrtGearPosition' }
sub XmNxrtGearPrintCallback () { 'xrtGearPrintCallback' }
sub XmNxrtGearProgressCallback () { 'xrtGearProgressCallback' }
sub XmNxrtGearProgressTimeOut () { 'xrtGearProgressTimeOut' }
sub XmNxrtGearProgressType () { 'xrtGearProgressType' }
sub XmNxrtGearRepaint () { 'xrtGearRepaint' }
sub XmNxrtGearResizeCallback () { 'xrtGearResizeCallback' }
sub XmNxrtGearResizeHeight () { 'xrtGearResizeHeight' }
sub XmNxrtGearResizeWidth () { 'xrtGearResizeWidth' }
sub XmNxrtGearRightSpace () { 'xrtGearRightSpace' }
sub XmNxrtGearRowSpacing () { 'xrtGearRowSpacing' }
sub XmNxrtGearScrollBarHoriz () { 'xrtGearScrollBarHoriz ' }
sub XmNxrtGearScrollBarHorizDisplayPolicy () { 'xrtGearScrollBarHorizDisplayPolicy' }
sub XmNxrtGearScrollBarVert () { 'xrtGearScrollBarVert' }
sub XmNxrtGearScrollBarVertDisplayPolicy () { 'xrtGearScrollBarVertDisplayPolicy' }
sub XmNxrtGearSearchPolicy () { 'xrtGearSearchPolicy' }
sub XmNxrtGearSelectColor () { 'xrtGearSelectColor' }
sub XmNxrtGearSelected () { 'xrtGearSelected' }
sub XmNxrtGearSelectedFontList () { 'xrtGearSelectedFontList' }
sub XmNxrtGearSelectedNodeList () { 'xrtGearSelectedNodeList' }
sub XmNxrtGearSelectionCallback () { 'xrtGearSelectionCallback' }
sub XmNxrtGearSelectionPolicy () { 'xrtGearSelectionPolicy' }
sub XmNxrtGearSelectionRestrictions () { 'xrtGearSelectionRestrictions' }
sub XmNxrtGearShadowThickness () { 'xrtGearShadowThickness' }
sub XmNxrtGearShortcutShow () { 'xrtGearShortcutShow' }
sub XmNxrtGearShortcutSize () { 'xrtGearShortcutSize' }
sub XmNxrtGearSnapNoShapeClip () { 'xrtGearSnapNoShapeClip' }
sub XmNxrtGearSpacing () { 'xrtGearSpacing' }
sub XmNxrtGearState () { 'xrtGearState' }
sub XmNxrtGearStateChangedCallback () { 'xrtGearStateChangedCallback' }
sub XmNxrtGearStringLayout () { 'xrtGearStringLayout' }
sub XmNxrtGearStringRotation () { 'xrtGearStringRotation' }
sub XmNxrtGearStyle () { 'xrtGearStyle' }
sub XmNxrtGearTabResize () { 'xrtGearTabResize' }
sub XmNxrtGearTabRotation () { 'xrtGearTabRotation' }
sub XmNxrtGearTabSide () { 'xrtGearTabSide' }
sub XmNxrtGearTabSpacing () { 'xrtGearTabSpacing' }
sub XmNxrtGearTabStretch () { 'xrtGearTabStretch' }
sub XmNxrtGearText () { 'xrtGearText' }
sub XmNxrtGearTextField () { 'xrtGearTextField' }
sub XmNxrtGearTextHorizClipPolicy () { 'xrtGearTextHorizClipPolicy' }
sub XmNxrtGearTextRelief () { 'xrtGearTextRelief' }
sub XmNxrtGearTipsBorderType () { 'xrtGearTipsBorderType' }
sub XmNxrtGearTopSpace () { 'xrtGearTopSpace' }
sub XmNxrtGearTreeData () { 'xrtGearTreeData' }
sub XmNxrtGearUnselectColor () { 'xrtGearUnselectColor' }
sub XmNxrtGearValuePercent () { 'xrtGearValuePercent' }
sub XmNxrtGearVisibleItemCount () { 'xrtGearVisibleItemCount' }
sub XmNxrtGearWidgetPosition () { 'xrtGearWidgetPosition' }
sub XmNxrtGearWidthChar () { 'xrtGearWidthChar' }
sub XmNxrtGearWidthList () { 'xrtGearWidthList' }
sub XmNxrtGearWidthMaximum () { 'xrtGearWidthMaximum' }
sub XmNxrtGearWidthMinimum () { 'xrtGearWidthMinimum' }
sub XmNxrtGearWidthPreferredCount () { 'xrtGearWidthPreferredCount' }
sub XmNxrtGearWidthResizePolicy () { 'xrtGearWidthResizePolicy' }
sub XmNxrtGearWidthSizingPolicy () { 'xrtGearWidthSizingPolicy' }
sub XmNxrtGearWidthVirtual () { 'xrtGearWidthVirtual' }
sub XmNxrtLblBackgroundString () { 'xrtLblBackgroundString' }
sub XmNxrtLblBorderType () { 'xrtLblBorderType' }
sub XmNxrtLblForegroundString () { 'xrtLblForegroundString' }
sub XmNxrtLblRotation () { 'xrtLblRotation' }
sub XmNxrtSpinArrowLayout () { 'xrtSpinArrowLayout' }
sub XmNxrtSpinArrowOrientation () { 'xrtSpinArrowOrientation' }
sub XmNxrtSpinArrowType () { 'xrtSpinArrowType' }
sub XmNxrtSpinDecrArrow () { 'xrtSpinDecrArrow' }
sub XmNxrtSpinDecrArrowClass () { 'xrtSpinDecrArrowClass' }
sub XmNxrtSpinField () { 'xrtSpinField' }
sub XmNxrtSpinFieldClass () { 'xrtSpinFieldClass' }
sub XmNxrtSpinFieldName () { 'xrtSpinFieldName' }
sub XmNxrtSpinFieldType () { 'xrtSpinFieldType' }
sub XmNxrtSpinIncrArrow () { 'xrtSpinIncrArrow' }
sub XmNxrtSpinIncrArrowClass () { 'xrtSpinIncrArrowClass' }
sub XmNxrtSpinSpacing () { 'xrtSpinSpacing' }
sub XmNxrtSpinType () { 'xrtSpinType' }
sub XmNxrtTblAlignmentContext () { 'xrtTblAlignmentContext' }
sub XmNxrtTblAlignmentSeries () { 'xrtTblAlignmentSeries' }
sub XmNxrtTblAllowCellResize () { 'xrtTblAllowCellResize' }
sub XmNxrtTblAllowResize () { 'xrtTblAllowResize' }
sub XmNxrtTblArgListContext () { 'xrtTblArgListContext' }
sub XmNxrtTblArgListSeries () { 'xrtTblArgListSeries' }
sub XmNxrtTblBackgroundContext () { 'xrtTblBackgroundContext' }
sub XmNxrtTblBackgroundPixelContext () { 'xrtTblBackgroundPixelContext' }
sub XmNxrtTblBackgroundSeries () { 'xrtTblBackgroundSeries' }
sub XmNxrtTblBackingStore () { 'xrtTblBackingStore' }
sub XmNxrtTblBorderSidesContext () { 'xrtTblBorderSidesContext' }
sub XmNxrtTblBorderSidesSeries () { 'xrtTblBorderSidesSeries' }
sub XmNxrtTblBorderTypeContext () { 'xrtTblBorderTypeContext' }
sub XmNxrtTblBorderTypeSeries () { 'xrtTblBorderTypeSeries' }
sub XmNxrtTblBottomOffset () { 'xrtTblBottomOffset' }
sub XmNxrtTblBottomShadowContext () { 'xrtTblBottomShadowContext' }
sub XmNxrtTblCaseContext () { 'xrtTblCaseContext' }
sub XmNxrtTblCaseSeries () { 'xrtTblCaseSeries' }
sub XmNxrtTblCellHeightContext () { 'xrtTblCellHeightContext' }
sub XmNxrtTblCellLocationX1Context () { 'xrtTblCellLocationX1Context' }
sub XmNxrtTblCellLocationX2Context () { 'xrtTblCellLocationX2Context' }
sub XmNxrtTblCellLocationY1Context () { 'xrtTblCellLocationY1Context' }
sub XmNxrtTblCellLocationY2Context () { 'xrtTblCellLocationY2Context' }
sub XmNxrtTblCellValueCallback () { 'xrtTblCellValueCallback' }
sub XmNxrtTblCellValueContext () { 'xrtTblCellValueContext' }
sub XmNxrtTblCellValueFunc () { 'xrtTblCellValueFunc' }
sub XmNxrtTblCellValues () { 'xrtTblCellValues' }
sub XmNxrtTblCellWidthContext () { 'xrtTblCellWidthContext' }
sub XmNxrtTblCharHeightContext () { 'xrtTblCharHeightContext' }
sub XmNxrtTblCharHeightSeries () { 'xrtTblCharHeightSeries' }
sub XmNxrtTblCharWidthContext () { 'xrtTblCharWidthContext' }
sub XmNxrtTblCharWidthSeries () { 'xrtTblCharWidthSeries' }
sub XmNxrtTblClipChildren () { 'xrtTblClipChildren' }
sub XmNxrtTblClipChildrenPersistent () { 'xrtTblClipChildrenPersistent' }
sub XmNxrtTblClipPixmapContext () { 'xrtTblClipPixmapContext' }
sub XmNxrtTblClipPixmapSeries () { 'xrtTblClipPixmapSeries' }
sub XmNxrtTblColumnLabelOffset () { 'xrtTblColumnLabelOffset' }
sub XmNxrtTblColumnLabelPlacement () { 'xrtTblColumnLabelPlacement' }
sub XmNxrtTblColumnLabels () { 'xrtTblColumnLabels' }
sub XmNxrtTblContext () { 'xrtTblContext' }
sub XmNxrtTblContextValueCallback () { 'xrtTblContextValueCallback' }
sub XmNxrtTblCreateWidgetCallback () { 'xrtTblCreateWidgetCallback' }
sub XmNxrtTblCursorCorner () { 'xrtTblCursorCorner' }
sub XmNxrtTblCursorHorizontal () { 'xrtTblCursorHorizontal' }
sub XmNxrtTblCursorNontraversable () { 'xrtTblCursorNontraversable' }
sub XmNxrtTblCursorTraversable () { 'xrtTblCursorTraversable' }
sub XmNxrtTblCursorVertical () { 'xrtTblCursorVertical' }
sub XmNxrtTblDataTypeContext () { 'xrtTblDataTypeContext' }
sub XmNxrtTblDataTypeList () { 'xrtTblDataTypeList' }
sub XmNxrtTblDataTypeSeries () { 'xrtTblDataTypeSeries' }
sub XmNxrtTblDebug () { 'xrtTblDebug' }
sub XmNxrtTblDisplayClipArrows () { 'xrtTblDisplayClipArrows' }
sub XmNxrtTblDisplayHorizScrollBar () { 'xrtTblDisplayHorizScrollBar' }
sub XmNxrtTblDisplayVertScrollBar () { 'xrtTblDisplayVertScrollBar' }
sub XmNxrtTblDisplayWidgetCallback () { 'xrtTblDisplayWidgetCallback' }
sub XmNxrtTblDoRepaint () { 'xrtTblDoRepaint' }
sub XmNxrtTblDoubleBuffer () { 'xrtTblDoubleBuffer' }
sub XmNxrtTblEditableContext () { 'xrtTblEditableContext' }
sub XmNxrtTblEditableSeries () { 'xrtTblEditableSeries' }
sub XmNxrtTblEnterCellCallback () { 'xrtTblEnterCellCallback' }
sub XmNxrtTblExportCallback () { 'xrtTblExportCallback' }
sub XmNxrtTblExportDelimiter () { 'xrtTblExportDelimiter' }
sub XmNxrtTblExportTargets () { 'xrtTblExportTargets' }
sub XmNxrtTblExposeCallback () { 'xrtTblExposeCallback' }
sub XmNxrtTblFieldArgListContext () { 'xrtTblFieldArgListContext' }
sub XmNxrtTblFieldArgListSeries () { 'xrtTblFieldArgListSeries' }
sub XmNxrtTblFontListContext () { 'xrtTblFontListContext' }
sub XmNxrtTblFontListSeries () { 'xrtTblFontListSeries' }
sub XmNxrtTblForegroundContext () { 'xrtTblForegroundContext' }
sub XmNxrtTblForegroundPixelContext () { 'xrtTblForegroundPixelContext' }
sub XmNxrtTblForegroundSeries () { 'xrtTblForegroundSeries' }
sub XmNxrtTblFrameBorderType () { 'xrtTblFrameBorderType' }
sub XmNxrtTblFrameShadowThickness () { 'xrtTblFrameShadowThickness' }
sub XmNxrtTblFrozenColumnPlacement () { 'xrtTblFrozenColumnPlacement' }
sub XmNxrtTblFrozenColumns () { 'xrtTblFrozenColumns' }
sub XmNxrtTblFrozenRowPlacement () { 'xrtTblFrozenRowPlacement' }
sub XmNxrtTblFrozenRows () { 'xrtTblFrozenRows' }
sub XmNxrtTblHorizScrollBarLeftAttachment () { 'xrtTblHorizScrollBarLeftAttachment' }
sub XmNxrtTblHorizScrollBarPlacement () { 'xrtTblHorizScrollBarPlacement' }
sub XmNxrtTblHorizScrollBarPosition () { 'xrtTblHorizScrollBarPosition' }
sub XmNxrtTblHorizScrollBarRightAttachment () { 'xrtTblHorizScrollBarRightAttachment' }
sub XmNxrtTblHorizontalScrollBar () { 'xrtTblHorizontalScrollBar' }
sub XmNxrtTblImportCallback () { 'xrtTblImportCallback' }
sub XmNxrtTblImportDelimiter () { 'xrtTblImportDelimiter' }
sub XmNxrtTblImportTargets () { 'xrtTblImportTargets' }
sub XmNxrtTblJumpScroll () { 'xrtTblJumpScroll' }
sub XmNxrtTblLabelContext () { 'xrtTblLabelContext' }
sub XmNxrtTblLabelCreateCallback () { 'xrtLabelCreateCallback' }
sub XmNxrtTblLabelCreateFunc () { 'xrtTblLabelCreateFunc' }
sub XmNxrtTblLeftColumn () { 'xrtTblLeftColumn' }
sub XmNxrtTblLeftOffset () { 'xrtTblLeftOffset' }
sub XmNxrtTblLocation () { 'xrtTblLocation' }
sub XmNxrtTblMarginHeight () { 'xrtTblMarginHeight' }
sub XmNxrtTblMarginWidth () { 'xrtTblMarginWidth' }
sub XmNxrtTblMaxLengthContext () { 'xrtTblMaxLengthContext' }
sub XmNxrtTblMaxLengthSeries () { 'xrtTblMaxLengthSeries' }
sub XmNxrtTblMinCellVisibility () { 'xrtTblMinCellVisibility' }
sub XmNxrtTblMinFlexibleHeight () { 'xrtTblMinFlexibleHeight' }
sub XmNxrtTblMinFlexibleWidth () { 'xrtTblMinFlexibleWidth' }
sub XmNxrtTblMode () { 'xrtTblMode' }
sub XmNxrtTblMultilineContext () { 'xrtTblMultilineContext' }
sub XmNxrtTblMultilineSeries () { 'xrtTblMultilineSeries' }
sub XmNxrtTblNumColumns () { 'xrtTblNumColumns' }
sub XmNxrtTblNumRows () { 'xrtTblNumRows' }
sub XmNxrtTblOverflowContext () { 'xrtTblOverflowContext' }
sub XmNxrtTblOverflowSeries () { 'xrtTblOverflowSeries' }
sub XmNxrtTblPSFontListContext () { 'xrtTblPSFontListContext' }
sub XmNxrtTblPSFontListSeries () { 'xrtTblPSFontListSeries' }
sub XmNxrtTblPSFontMapList () { 'xrtTblPSFontMapList' }
sub XmNxrtTblPixelHeightContext () { 'xrtTblPixelHeightContext' }
sub XmNxrtTblPixelHeightSeries () { 'xrtTblPixelHeightSeries' }
sub XmNxrtTblPixelWidthContext () { 'xrtTblPixelWidthContext' }
sub XmNxrtTblPixelWidthSeries () { 'xrtTblPixelWidthSeries' }
sub XmNxrtTblPixmapContext () { 'xrtTblPixmapContext' }
sub XmNxrtTblPixmapLayoutContext () { 'xrtTblPixmapLayoutContext' }
sub XmNxrtTblPixmapLayoutSeries () { 'xrtTblPixmapLayoutSeries' }
sub XmNxrtTblPixmapSeries () { 'xrtTblPixmapSeries' }
sub XmNxrtTblPixmapShadowContext () { 'xrtTblPixmapShadowContext' }
sub XmNxrtTblPixmapShadowSeries () { 'xrtTblPixmapShadowSeries' }
sub XmNxrtTblPrintCallback () { 'xrtTblPrintCallback' }
sub XmNxrtTblPrintWidgetCallback () { 'xrtTblPrintWidgetCallback' }
sub XmNxrtTblRangeContext () { 'xrtTblRangeContext' }
sub XmNxrtTblRepaint () { 'xrtTblRepaint' }
sub XmNxrtTblRepeatBackgroundColors () { 'xrtTblRepeatBackgroundColors' }
sub XmNxrtTblRepeatForegroundColors () { 'xrtTblRepeatForegroundColors' }
sub XmNxrtTblResizeCallback () { 'xrtTblResizeCallback' }
sub XmNxrtTblResizeCellCallback () { 'xrtTblResizeCellCallback' }
sub XmNxrtTblRightOffset () { 'xrtTblRightOffset' }
sub XmNxrtTblRowLabelOffset () { 'xrtTblRowLabelOffset' }
sub XmNxrtTblRowLabelPlacement () { 'xrtTblRowLabelPlacement' }
sub XmNxrtTblRowLabels () { 'xrtTblRowLabels' }
sub XmNxrtTblScrollCallback () { 'xrtTblScrollCallback' }
sub XmNxrtTblSelectCallback () { 'xrtTblSelectCallback' }
sub XmNxrtTblSelectedBackground () { 'xrtTblSelectedBackground' }
sub XmNxrtTblSelectedCellList () { 'xrtTblSelectedCellList' }
sub XmNxrtTblSelectedForeground () { 'xrtTblSelectedForeground' }
sub XmNxrtTblSelectionPolicy () { 'xrtTblSelectionPolicy' }
sub XmNxrtTblSetTextCursorPos () { 'xrtTblSetTextCursorPos' }
sub XmNxrtTblShadowThickness () { 'xrtTblShadowThickness' }
sub XmNxrtTblSortCallback () { 'xrtTblSortCallback' }
sub XmNxrtTblSpace () { 'xrtTblSpace' }
sub XmNxrtTblSpanList () { 'xrtTblSpanList' }
sub XmNxrtTblText () { 'xrtTblText' }
sub XmNxrtTblTextInitSelect () { 'xrtTblTextInitSelect' }
sub XmNxrtTblTopOffset () { 'xrtTblTopOffset' }
sub XmNxrtTblTopRow () { 'xrtTblTopRow' }
sub XmNxrtTblTopShadowContext () { 'xrtTblTopShadowContext' }
sub XmNxrtTblTrackCursor () { 'xrtTblTrackCursor' }
sub XmNxrtTblTrackCursorCallback () { 'xrtTblTrackCursorCallback' }
sub XmNxrtTblTraversableContext () { 'xrtTblTraversableContext' }
sub XmNxrtTblTraversableSeries () { 'xrtTblTraversableSeries' }
sub XmNxrtTblTraverseCellCallback () { 'xrtTblTraverseCellCallback' }
sub XmNxrtTblUseXmGetColors () { 'xrtTblUseXmGetColors' }
sub XmNxrtTblUserDataContext () { 'xrtTblUserDataContext' }
sub XmNxrtTblUserDataSeries () { 'xrtTblUserDataSeries' }
sub XmNxrtTblValidateCellCallback () { 'xrtTblValidateCellCallback' }
sub XmNxrtTblValidatePolicy () { 'xrtTblValidatePolicy' }
sub XmNxrtTblVertScrollBarBottomAttachment () { 'xrtTblVertScrollBarBottomAttachment' }
sub XmNxrtTblVertScrollBarPlacement () { 'xrtTblVertScrollBarPlacement' }
sub XmNxrtTblVertScrollBarPosition () { 'xrtTblVertScrollBarPosition' }
sub XmNxrtTblVertScrollBarTopAttachment () { 'xrtTblVertScrollBarTopAttachment' }
sub XmNxrtTblVerticalScrollBar () { 'xrtTblVerticalScrollBar' }
sub XmNxrtTblVisibleColumns () { 'xrtTblVisibleColumns' }
sub XmNxrtTblVisibleRows () { 'xrtTblVisibleRows' }
sub XmNxrtTblWidgetClassList () { 'xrtTblWidgetClassList' }
sub XmNxrtTblWidgetContext () { 'xrtTblWidgetContext' }
sub XmNxrtTblWidgetLocation () { 'xrtTblWidgetLocation' }
sub XmNxrtTblWidgetSeries () { 'xrtTblWidgetSeries' }
sub XmNxrtTblWidgetSetValueCallback () { 'xrtTblWidgetSetValueCallback' }
sub XmNxrtTblWidgetShadowContext () { 'xrtTblWidgetShadowContext' }
sub XmNxrtTblWidgetShadowSeries () { 'xrtTblWidgetShadowSeries' }
sub XmNxrtTblWordWrapContext () { 'xrtTblWordWrapContext' }
sub XmNxrtTblWordWrapSeries () { 'xrtTblWordWrapSeries' }
sub XmNxrtTblXmStringGetMode () { 'xrtTblXmStringGetMode' }
sub XmNxrtTblXmStringSetMode () { 'xrtTblXmStringSetMode' }
sub XtNxrt3dAxisStrokeFont () { 'xrt3dAxisStrokeFont' }
sub XtNxrt3dAxisStrokeSize () { 'xrt3dAxisStrokeSize' }
sub XtNxrt3dAxisTitleStrokeFont () { 'xrt3dAxisTitleStrokeFont' }
sub XtNxrt3dAxisTitleStrokeSize () { 'xrt3dAxisTitleStrokeSize' }
sub XtNxrt3dBackgroundColor () { 'xrt3dBackgroundColor' }
sub XtNxrt3dContourStyles () { 'xrt3dContourStyles' }
sub XtNxrt3dDataAreaBackgroundColor () { 'xrt3dDataAreaBackgroundColor' }
sub XtNxrt3dDebug () { 'xrt3dDebug' }
sub XtNxrt3dDistnMethod () { 'xrt3dDistnMethod' }
sub XtNxrt3dDistnTable () { 'xrt3dDistnTable' }
sub XtNxrt3dDoubleBuffer () { 'xrt3dDoubleBuffer' }
sub XtNxrt3dDrawContours () { 'xrt3dDrawContours' }
sub XtNxrt3dDrawHiddenLines () { 'xrt3dDrawHiddenLines' }
sub XtNxrt3dDrawMesh () { 'xrt3dDrawMesh' }
sub XtNxrt3dDrawShaded () { 'xrt3dDrawShaded' }
sub XtNxrt3dDrawZones () { 'xrt3dDrawZones' }
sub XtNxrt3dExposeCallback () { 'xrt3dExposeCallback' }
sub XtNxrt3dFooterAdjust () { 'xrt3dFooterAdjust' }
sub XtNxrt3dFooterBackgroundColor () { 'xrt3dFooterBackgroundColor' }
sub XtNxrt3dFooterBorder () { 'xrt3dFooterBorder' }
sub XtNxrt3dFooterBorderWidth () { 'xrt3dFooterBorderWidth' }
sub XtNxrt3dFooterFont () { 'xrt3dFooterFont' }
sub XtNxrt3dFooterForegroundColor () { 'xrt3dFooterForegroundColor' }
sub XtNxrt3dFooterHeight () { 'xrt3dFooterHeight' }
sub XtNxrt3dFooterStrings () { 'xrt3dFooterStrings' }
sub XtNxrt3dFooterWidth () { 'xrt3dFooterWidth' }
sub XtNxrt3dFooterX () { 'xrt3dFooterX' }
sub XtNxrt3dFooterXUseDefault () { 'xrt3dFooterXUseDefault' }
sub XtNxrt3dFooterY () { 'xrt3dFooterY' }
sub XtNxrt3dFooterYUseDefault () { 'xrt3dFooterYUseDefault' }
sub XtNxrt3dForegroundColor () { 'xrt3dForegroundColor' }
sub XtNxrt3dGraphBackgroundColor () { 'xrt3dGraphBackgroundColor' }
sub XtNxrt3dGraphBorder () { 'xrt3dGraphBorder' }
sub XtNxrt3dGraphBorderWidth () { 'xrt3dGraphBorderWidth' }
sub XtNxrt3dGraphForegroundColor () { 'xrt3dGraphForegroundColor' }
sub XtNxrt3dGraphHeight () { 'xrt3dGraphHeight' }
sub XtNxrt3dGraphHeightUseDefault () { 'xrt3dGraphHeightUseDefault' }
sub XtNxrt3dGraphWidth () { 'xrt3dGraphWidth' }
sub XtNxrt3dGraphWidthUseDefault () { 'xrt3dGraphWidthUseDefault' }
sub XtNxrt3dGraphX () { 'xrt3dGraphX' }
sub XtNxrt3dGraphXUseDefault () { 'xrt3dGraphXUseDefault' }
sub XtNxrt3dGraphY () { 'xrt3dGraphY' }
sub XtNxrt3dGraphYUseDefault () { 'xrt3dGraphYUseDefault' }
sub XtNxrt3dHeaderAdjust () { 'xrt3dHeaderAdjust' }
sub XtNxrt3dHeaderBackgroundColor () { 'xrt3dHeaderBackgroundColor' }
sub XtNxrt3dHeaderBorder () { 'xrt3dHeaderBorder' }
sub XtNxrt3dHeaderBorderWidth () { 'xrt3dHeaderBorderWidth' }
sub XtNxrt3dHeaderFont () { 'xrt3dHeaderFont' }
sub XtNxrt3dHeaderForegroundColor () { 'xrt3dHeaderForegroundColor' }
sub XtNxrt3dHeaderHeight () { 'xrt3dHeaderHeight' }
sub XtNxrt3dHeaderStrings () { 'xrt3dHeaderStrings' }
sub XtNxrt3dHeaderWidth () { 'xrt3dHeaderWidth' }
sub XtNxrt3dHeaderX () { 'xrt3dHeaderX' }
sub XtNxrt3dHeaderXUseDefault () { 'xrt3dHeaderXUseDefault' }
sub XtNxrt3dHeaderY () { 'xrt3dHeaderY' }
sub XtNxrt3dHeaderYUseDefault () { 'xrt3dHeaderYUseDefault' }
sub XtNxrt3dLegendAnchor () { 'xrt3dLegendAnchor' }
sub XtNxrt3dLegendBackgroundColor () { 'xrt3dLegendBackgroundColor' }
sub XtNxrt3dLegendBorder () { 'xrt3dLegendBorder' }
sub XtNxrt3dLegendBorderWidth () { 'xrt3dLegendBorderWidth' }
sub XtNxrt3dLegendFont () { 'xrt3dLegendFont' }
sub XtNxrt3dLegendForegroundColor () { 'xrt3dLegendForegroundColor' }
sub XtNxrt3dLegendHeight () { 'xrt3dLegendHeight' }
sub XtNxrt3dLegendLabelFunc () { 'xrt3dLegendLabelFunc' }
sub XtNxrt3dLegendOrientation () { 'xrt3dLegendOrientation' }
sub XtNxrt3dLegendShow () { 'xrt3dLegendShow' }
sub XtNxrt3dLegendStrings () { 'xrt3dLegendStrings' }
sub XtNxrt3dLegendStyle () { 'xrt3dLegendStyle' }
sub XtNxrt3dLegendWidth () { 'xrt3dLegendWidth' }
sub XtNxrt3dLegendX () { 'xrt3dLegendX' }
sub XtNxrt3dLegendXUseDefault () { 'xrt3dLegendXUseDefault' }
sub XtNxrt3dLegendY () { 'xrt3dLegendY' }
sub XtNxrt3dLegendYUseDefault () { 'xrt3dLegendYUseDefault' }
sub XtNxrt3dMapCallback () { 'xrt3dMapCallback' }
sub XtNxrt3dMeshBottomColor () { 'xrt3dMeshBottomColor' }
sub XtNxrt3dMeshTopColor () { 'xrt3dMeshTopColor' }
sub XtNxrt3dModifyCallback () { 'xrt3dModifyCallback' }
sub XtNxrt3dNumDistnLevels () { 'xrt3dNumDistnLevels' }
sub XtNxrt3dPerspectiveDepth () { 'xrt3dPerspectiveDepth' }
sub XtNxrt3dPickCallback () { 'xrt3dPickCallback' }
sub XtNxrt3dPreviewMethod () { 'xrt3dPreviewMethod' }
sub XtNxrt3dProjectZMax () { 'xrt3dProjectZMax' }
sub XtNxrt3dProjectZMin () { 'xrt3dProjectZMin' }
sub XtNxrt3dRepaint () { 'xrt3dRepaint' }
sub XtNxrt3dResizeCallback () { 'xrt3dResizeCallback' }
sub XtNxrt3dRotateCallback () { 'xrt3dRotateCallback' }
sub XtNxrt3dSolidSurface () { 'xrt3dSolidSurface' }
sub XtNxrt3dSurfaceBottomColor () { 'xrt3dSurfaceBottomColor' }
sub XtNxrt3dSurfaceData () { 'xrt3dSurfaceData' }
sub XtNxrt3dSurfaceTopColor () { 'xrt3dSurfaceTopColor' }
sub XtNxrt3dTextAdjust () { 'xrt3dTextAdjust' }
sub XtNxrt3dTextAttachIndexX () { 'xrt3dTextAttachIndexX' }
sub XtNxrt3dTextAttachIndexY () { 'xrt3dTextAttachIndexY' }
sub XtNxrt3dTextAttachMethod () { 'xrt3dTextAttachMethod' }
sub XtNxrt3dTextAttachPixelX () { 'xrt3dTextAttachPixelX' }
sub XtNxrt3dTextAttachPixelY () { 'xrt3dTextAttachPixelY' }
sub XtNxrt3dTextAttachPointX () { 'xrt3dTextAttachPointX' }
sub XtNxrt3dTextAttachPointY () { 'xrt3dTextAttachPointY' }
sub XtNxrt3dTextAttachPointZ () { 'xrt3dTextAttachPointZ' }
sub XtNxrt3dTextBackgroundColor () { 'xrt3dTextBackgroundColor' }
sub XtNxrt3dTextBorder () { 'xrt3dTextBorder' }
sub XtNxrt3dTextBorderWidth () { 'xrt3dTextBorderWidth' }
sub XtNxrt3dTextFont () { 'xrt3dTextFont' }
sub XtNxrt3dTextForegroundColor () { 'xrt3dTextForegroundColor' }
sub XtNxrt3dTextLineShow () { 'xrt3dTextLineShow' }
sub XtNxrt3dTextList () { 'xrt3dTextList' }
sub XtNxrt3dTextOffsetX () { 'xrt3dTextOffsetX' }
sub XtNxrt3dTextOffsetY () { 'xrt3dTextOffsetY' }
sub XtNxrt3dTextPlane () { 'xrt3dTextPlane' }
sub XtNxrt3dTextPrintFont () { 'xrt3dTextPrintFont' }
sub XtNxrt3dTextShow () { 'xrt3dTextShow' }
sub XtNxrt3dTextStrings () { 'xrt3dTextStrings' }
sub XtNxrt3dTextStrokeFont () { 'xrt3dTextStrokeFont' }
sub XtNxrt3dTextStrokeSize () { 'xrt3dTextStrokeSize' }
sub XtNxrt3dTransformCallback () { 'xrt3dTransformCallback' }
sub XtNxrt3dType () { 'xrt3dType' }
sub XtNxrt3dViewNormalized () { 'xrt3dViewNormalized' }
sub XtNxrt3dViewScale () { 'xrt3dViewScale' }
sub XtNxrt3dViewXTranslate () { 'xrt3dViewXTranslate' }
sub XtNxrt3dViewYTranslate () { 'xrt3dViewYTranslate' }
sub XtNxrt3dXAnnoMethod () { 'xrt3dXAnnoMethod' }
sub XtNxrt3dXAxisShow () { 'xrt3dXAxisShow' }
sub XtNxrt3dXAxisTitle () { 'xrt3dXAxisTitle' }
sub XtNxrt3dXBarFormat () { 'xrt3dXBarFormat' }
sub XtNxrt3dXBarSpacing () { 'xrt3dXBarSpacing' }
sub XtNxrt3dXDataLabels () { 'xrt3dXDataLabels' }
sub XtNxrt3dXGridLines () { 'xrt3dXGridLines' }
sub XtNxrt3dXMax () { 'xrt3dXMax' }
sub XtNxrt3dXMaxUseDefault () { 'xrt3dXMaxUseDefault' }
sub XtNxrt3dXMeshFilter () { 'xrt3dXMeshFilter' }
sub XtNxrt3dXMeshShow () { 'xrt3dXMeshShow' }
sub XtNxrt3dXMin () { 'xrt3dXMin' }
sub XtNxrt3dXMinUseDefault () { 'xrt3dXMinUseDefault' }
sub XtNxrt3dXRotation () { 'xrt3dXRotation' }
sub XtNxrt3dXScale () { 'xrt3dXScale' }
sub XtNxrt3dXValueLabels () { 'xrt3dXValueLabels' }
sub XtNxrt3dXYColors () { 'xrt3dXYColors' }
sub XtNxrt3dYAnnoMethod () { 'xrt3dYAnnoMethod' }
sub XtNxrt3dYAxisShow () { 'xrt3dYAxisShow' }
sub XtNxrt3dYAxisTitle () { 'xrt3dYAxisTitle' }
sub XtNxrt3dYBarFormat () { 'xrt3dYBarFormat' }
sub XtNxrt3dYBarSpacing () { 'xrt3dYBarSpacing' }
sub XtNxrt3dYDataLabels () { 'xrt3dYDataLabels' }
sub XtNxrt3dYGridLines () { 'xrt3dYGridLines' }
sub XtNxrt3dYMax () { 'xrt3dYMax' }
sub XtNxrt3dYMaxUseDefault () { 'xrt3dYMaxUseDefault' }
sub XtNxrt3dYMeshFilter () { 'xrt3dYMeshFilter' }
sub XtNxrt3dYMeshShow () { 'xrt3dYMeshShow' }
sub XtNxrt3dYMin () { 'xrt3dYMin' }
sub XtNxrt3dYMinUseDefault () { 'xrt3dYMinUseDefault' }
sub XtNxrt3dYRotation () { 'xrt3dYRotation' }
sub XtNxrt3dYScale () { 'xrt3dYScale' }
sub XtNxrt3dYValueLabels () { 'xrt3dYValueLabels' }
sub XtNxrt3dZAnnoMethod () { 'xrt3dZAnnoMethod' }
sub XtNxrt3dZAxisShow () { 'xrt3dZAxisShow' }
sub XtNxrt3dZAxisTitle () { 'xrt3dZAxisTitle' }
sub XtNxrt3dZGridLines () { 'xrt3dZGridLines' }
sub XtNxrt3dZMax () { 'xrt3dZMax' }
sub XtNxrt3dZMaxUseDefault () { 'xrt3dZMaxUseDefault' }
sub XtNxrt3dZMin () { 'xrt3dZMin' }
sub XtNxrt3dZMinUseDefault () { 'xrt3dZMinUseDefault' }
sub XtNxrt3dZOrigin () { 'xrt3dZOrigin' }
sub XtNxrt3dZRotation () { 'xrt3dZRotation' }
sub XtNxrt3dZScale () { 'xrt3dZScale' }
sub XtNxrt3dZValueLabels () { 'xrt3dZValueLabels' }
sub XtNxrt3dZoneData () { 'xrt3dZoneData' }
sub XtNxrt3dZoneMethod () { 'xrt3dZoneMethod' }
sub XtNxrtAngleUnit () { 'xrtAngleUnit' }
sub XtNxrtAxisBoundingBox () { 'xrtAxisBoundingBox' }
sub XtNxrtAxisFont () { 'xrtAxisFont' }
sub XtNxrtBackgroundColor () { 'xrtBackgroundColor' }
sub XtNxrtBarClusterOverlap () { 'xrtBarClusterOverlap' }
sub XtNxrtBarClusterWidth () { 'xrtBarClusterWidth' }
sub XtNxrtBorder () { 'xrtBorder' }
sub XtNxrtCandleComplex () { 'xrtCandleComplex' }
sub XtNxrtData () { 'xrtData' }
sub XtNxrtData2 () { 'xrtData2' }
sub XtNxrtDataAreaBackgroundColor () { 'xrtDataAreaBackgroundColor' }
sub XtNxrtDataAreaForegroundColor () { 'xrtDataAreaForegroundColor' }
sub XtNxrtDataStyles () { 'xrtDataStyles' }
sub XtNxrtDataStyles2 () { 'xrtDataStyles2' }
sub XtNxrtDataStyles2UseDefault () { 'xrtDataStyles2UseDefault' }
sub XtNxrtDataStylesUseDefault () { 'xrtDataStylesUseDefault' }
sub XtNxrtDebug () { 'xrtDebug' }
sub XtNxrtDoubleBuffer () { 'xrtDoubleBuffer' }
sub XtNxrtExposeCallback () { 'xrtExposeCallback' }
sub XtNxrtFooterAdjust () { 'xrtFooterAdjust' }
sub XtNxrtFooterBackgroundColor () { 'xrtFooterBackgroundColor' }
sub XtNxrtFooterBorder () { 'xrtFooterBorder' }
sub XtNxrtFooterBorderWidth () { 'xrtFooterBorderWidth' }
sub XtNxrtFooterFont () { 'xrtFooterFont' }
sub XtNxrtFooterForegroundColor () { 'xrtFooterForegroundColor' }
sub XtNxrtFooterHeight () { 'xrtFooterHeight' }
sub XtNxrtFooterStrings () { 'xrtFooterStrings' }
sub XtNxrtFooterWidth () { 'xrtFooterWidth' }
sub XtNxrtFooterX () { 'xrtFooterX' }
sub XtNxrtFooterXUseDefault () { 'xrtFooterXUseDefault' }
sub XtNxrtFooterY () { 'xrtFooterY' }
sub XtNxrtFooterYUseDefault () { 'xrtFooterYUseDefault' }
sub XtNxrtForegroundColor () { 'xrtForegroundColor' }
sub XtNxrtFrontDataset () { 'xrtFrontDataset' }
sub XtNxrtGraph3dShading () { 'xrtGraph3dShading' }
sub XtNxrtGraphBackgroundColor () { 'xrtGraphBackgroundColor' }
sub XtNxrtGraphBorder () { 'xrtGraphBorder' }
sub XtNxrtGraphBorderWidth () { 'xrtGraphBorderWidth' }
sub XtNxrtGraphDepth () { 'xrtGraphDepth' }
sub XtNxrtGraphForegroundColor () { 'xrtGraphForegroundColor' }
sub XtNxrtGraphHeight () { 'xrtGraphHeight' }
sub XtNxrtGraphHeightUseDefault () { 'xrtGraphHeightUseDefault' }
sub XtNxrtGraphInclination () { 'xrtGraphInclination' }
sub XtNxrtGraphMarginBottom () { 'xrtGraphMarginBottom' }
sub XtNxrtGraphMarginBottomUseDefault () { 'xrtGraphMarginBottomUseDefault' }
sub XtNxrtGraphMarginLeft () { 'xrtGraphMarginLeft' }
sub XtNxrtGraphMarginLeftUseDefault () { 'xrtGraphMarginLeftUseDefault' }
sub XtNxrtGraphMarginRight () { 'xrtGraphMarginRight' }
sub XtNxrtGraphMarginRightUseDefault () { 'xrtGraphMarginRightUseDefault' }
sub XtNxrtGraphMarginTop () { 'xrtGraphMarginTop' }
sub XtNxrtGraphMarginTopUseDefault () { 'xrtGraphMarginTopUseDefault' }
sub XtNxrtGraphRotation () { 'xrtGraphRotation' }
sub XtNxrtGraphShowOutlines () { 'xrtGraphShowOutlines' }
sub XtNxrtGraphWidth () { 'xrtGraphWidth' }
sub XtNxrtGraphWidthUseDefault () { 'xrtGraphWidthUseDefault' }
sub XtNxrtGraphX () { 'xrtGraphX' }
sub XtNxrtGraphXUseDefault () { 'xrtGraphXUseDefault' }
sub XtNxrtGraphY () { 'xrtGraphY' }
sub XtNxrtGraphYUseDefault () { 'xrtGraphYUseDefault' }
sub XtNxrtHeaderAdjust () { 'xrtHeaderAdjust' }
sub XtNxrtHeaderBackgroundColor () { 'xrtHeaderBackgroundColor' }
sub XtNxrtHeaderBorder () { 'xrtHeaderBorder' }
sub XtNxrtHeaderBorderWidth () { 'xrtHeaderBorderWidth' }
sub XtNxrtHeaderFont () { 'xrtHeaderFont' }
sub XtNxrtHeaderForegroundColor () { 'xrtHeaderForegroundColor' }
sub XtNxrtHeaderHeight () { 'xrtHeaderHeight' }
sub XtNxrtHeaderStrings () { 'xrtHeaderStrings' }
sub XtNxrtHeaderWidth () { 'xrtHeaderWidth' }
sub XtNxrtHeaderX () { 'xrtHeaderX' }
sub XtNxrtHeaderXUseDefault () { 'xrtHeaderXUseDefault' }
sub XtNxrtHeaderY () { 'xrtHeaderY' }
sub XtNxrtHeaderYUseDefault () { 'xrtHeaderYUseDefault' }
sub XtNxrtHiLoCloseShow () { 'xrtHiLoCloseShow' }
sub XtNxrtHiLoOpenCloseFullWidth () { 'xrtHiLoOpenCloseFullWidth' }
sub XtNxrtHiLoOpenShow () { 'xrtHiLoOpenShow' }
sub XtNxrtInvertOrientation () { 'xrtInvertOrientation' }
sub XtNxrtLegendAnchor () { 'xrtLegendAnchor' }
sub XtNxrtLegendBackgroundColor () { 'xrtLegendBackgroundColor' }
sub XtNxrtLegendBorder () { 'xrtLegendBorder' }
sub XtNxrtLegendBorderWidth () { 'xrtLegendBorderWidth' }
sub XtNxrtLegendFont () { 'xrtLegendFont' }
sub XtNxrtLegendForegroundColor () { 'xrtLegendForegroundColor' }
sub XtNxrtLegendHeight () { 'xrtLegendHeight' }
sub XtNxrtLegendOrientation () { 'xrtLegendOrientation' }
sub XtNxrtLegendShow () { 'xrtLegendShow' }
sub XtNxrtLegendWidth () { 'xrtLegendWidth' }
sub XtNxrtLegendX () { 'xrtLegendX' }
sub XtNxrtLegendXUseDefault () { 'xrtLegendXUseDefault' }
sub XtNxrtLegendY () { 'xrtLegendY' }
sub XtNxrtLegendYUseDefault () { 'xrtLegendYUseDefault' }
sub XtNxrtMapCallback () { 'xrtMapCallback' }
sub XtNxrtMarkerDataStyle () { 'xrtMarkerDataStyle' }
sub XtNxrtMarkerDataStyleUseDefault () { 'xrtMarkerDataStyleUseDefault' }
sub XtNxrtMarkerDataset () { 'xrtMarkerDataset' }
sub XtNxrtModifyCallback () { 'xrtModifyCallback' }
sub XtNxrtOtherDataStyle () { 'xrtOtherDataStyle' }
sub XtNxrtOtherDataStyleUseDefault () { 'xrtOtherDataStyleUseDefault' }
sub XtNxrtOtherLabel () { 'xrtOtherLabel' }
sub XtNxrtPickCallback () { 'xrtPickCallback' }
sub XtNxrtPieMinSlices () { 'xrtPieMinSlices' }
sub XtNxrtPieOrder () { 'xrtPieOrder' }
sub XtNxrtPieThresholdMethod () { 'xrtPieThresholdMethod' }
sub XtNxrtPieThresholdValue () { 'xrtPieThresholdValue' }
sub XtNxrtPointLabels () { 'xrtPointLabels' }
sub XtNxrtPointLabels2 () { 'xrtPointLabels2' }
sub XtNxrtPolarHalfRange () { 'xrtPolarHalfRange' }
sub XtNxrtRepaint () { 'xrtRepaint' }
sub XtNxrtResizeCallback () { 'xrtResizeCallback' }
sub XtNxrtRotateCallback () { 'xrtRotateCallback' }
sub XtNxrtSetLabels () { 'xrtSetLabels' }
sub XtNxrtSetLabels2 () { 'xrtSetLabels2' }
sub XtNxrtTimeBase () { 'xrtTimeBase' }
sub XtNxrtTimeFormat () { 'xrtTimeFormat' }
sub XtNxrtTimeFormatUseDefault () { 'xrtTimeFormatUseDefault' }
sub XtNxrtTimeUnit () { 'xrtTimeUnit' }
sub XtNxrtTransformCallback () { 'xrtTransformCallback' }
sub XtNxrtType () { 'xrtType' }
sub XtNxrtType2 () { 'xrtType2' }
sub XtNxrtXAnnoPlacement () { 'xrtXAnnoPlacement' }
sub XtNxrtXAnnotationMethod () { 'xrtXAnnotationMethod' }
sub XtNxrtXAnnotationRotation () { 'xrtXAnnotationRotation' }
sub XtNxrtXAxisLabelFormat () { 'xrtXAxisLabelFormat' }
sub XtNxrtXAxisLogarithmic () { 'xrtXAxisLogarithmic' }
sub XtNxrtXAxisMax () { 'xrtXAxisMax' }
sub XtNxrtXAxisMaxUseDefault () { 'xrtXAxisMaxUseDefault' }
sub XtNxrtXAxisMin () { 'xrtXAxisMin' }
sub XtNxrtXAxisMinUseDefault () { 'xrtXAxisMinUseDefault' }
sub XtNxrtXAxisReversed () { 'xrtXAxisReversed' }
sub XtNxrtXAxisShow () { 'xrtXAxisShow' }
sub XtNxrtXGrid () { 'xrtXGrid' }
sub XtNxrtXGridDataStyle () { 'xrtXGridDataStyle' }
sub XtNxrtXGridDataStyleUseDefault () { 'xrtXGridDataStyleUseDefault' }
sub XtNxrtXGridUseDefault () { 'xrtXGridUseDefault' }
sub XtNxrtXLabels () { 'xrtXLabels' }
sub XtNxrtXMarker () { 'xrtXMarker' }
sub XtNxrtXMarkerDataStyle () { 'xrtXMarkerDataStyle' }
sub XtNxrtXMarkerDataStyleUseDefault () { 'xrtXMarkerDataStyleUseDefault' }
sub XtNxrtXMarkerMethod () { 'xrtXMarkerMethod' }
sub XtNxrtXMarkerPoint () { 'xrtXMarkerPoint' }
sub XtNxrtXMarkerSet () { 'xrtXMarkerSet' }
sub XtNxrtXMarkerShow () { 'xrtXMarkerShow' }
sub XtNxrtXMax () { 'xrtXMax' }
sub XtNxrtXMaxUseDefault () { 'xrtXMaxUseDefault' }
sub XtNxrtXMin () { 'xrtXMin' }
sub XtNxrtXMinUseDefault () { 'xrtXMinUseDefault' }
sub XtNxrtXNum () { 'xrtXNum' }
sub XtNxrtXNumMethod () { 'xrtXNumMethod' }
sub XtNxrtXNumUseDefault () { 'xrtXNumUseDefault' }
sub XtNxrtXOrigin () { 'xrtXOrigin' }
sub XtNxrtXOriginBase () { 'xrtXOriginBase' }
sub XtNxrtXOriginPlacement () { 'xrtXOriginPlacement' }
sub XtNxrtXOriginUseDefault () { 'xrtXOriginUseDefault' }
sub XtNxrtXPrecision () { 'xrtXPrecision' }
sub XtNxrtXPrecisionUseDefault () { 'xrtXPrecisionUseDefault' }
sub XtNxrtXTick () { 'xrtXTick' }
sub XtNxrtXTickUseDefault () { 'xrtXTickUseDefault' }
sub XtNxrtXTitle () { 'xrtXTitle' }
sub XtNxrtXTitleRotation () { 'xrtXTitleRotation' }
sub XtNxrtY2AnnoPlacement () { 'xrtY2AnnoPlacement' }
sub XtNxrtY2AnnotationAngle () { 'xrtY2AnnotationAngle' }
sub XtNxrtY2AnnotationAngleUseDefault () { 'xrtY2AnnotationAngleUseDefault' }
sub XtNxrtY2AnnotationMethod () { 'xrtY2AnnotationMethod' }
sub XtNxrtY2AnnotationRotation () { 'xrtY2AnnotationRotation' }
sub XtNxrtY2Axis100Percent () { 'xrtY2Axis100Percent' }
sub XtNxrtY2AxisLabelFormat () { 'xrtY2AxisLabelFormat' }
sub XtNxrtY2AxisLogarithmic () { 'xrtY2AxisLogarithmic' }
sub XtNxrtY2AxisMax () { 'xrtY2AxisMax' }
sub XtNxrtY2AxisMaxUseDefault () { 'xrtY2AxisMaxUseDefault' }
sub XtNxrtY2AxisMin () { 'xrtY2AxisMin' }
sub XtNxrtY2AxisMinUseDefault () { 'xrtY2AxisMinUseDefault' }
sub XtNxrtY2AxisReversed () { 'xrtY2AxisReversed' }
sub XtNxrtY2AxisShow () { 'xrtY2AxisShow' }
sub XtNxrtY2Grid () { 'xrtY2Grid' }
sub XtNxrtY2GridDataStyle () { 'xrtY2GridDataStyle' }
sub XtNxrtY2GridDataStyleUseDefault () { 'xrtY2GridDataStyleUseDefault' }
sub XtNxrtY2GridUseDefault () { 'xrtY2GridUseDefault' }
sub XtNxrtY2Labels () { 'xrtY2Labels' }
sub XtNxrtY2Max () { 'xrtY2Max' }
sub XtNxrtY2MaxUseDefault () { 'xrtY2MaxUseDefault' }
sub XtNxrtY2Min () { 'xrtY2Min' }
sub XtNxrtY2MinUseDefault () { 'xrtY2MinUseDefault' }
sub XtNxrtY2Num () { 'xrtY2Num' }
sub XtNxrtY2NumMethod () { 'xrtY2NumMethod' }
sub XtNxrtY2NumUseDefault () { 'xrtY2NumUseDefault' }
sub XtNxrtY2Origin () { 'xrtY2Origin' }
sub XtNxrtY2OriginPlacement () { 'xrtY2OriginPlacement' }
sub XtNxrtY2OriginUseDefault () { 'xrtY2OriginUseDefault' }
sub XtNxrtY2Precision () { 'xrtY2Precision' }
sub XtNxrtY2PrecisionUseDefault () { 'xrtY2PrecisionUseDefault' }
sub XtNxrtY2Tick () { 'xrtY2Tick' }
sub XtNxrtY2TickUseDefault () { 'xrtY2TickUseDefault' }
sub XtNxrtY2Title () { 'xrtY2Title' }
sub XtNxrtY2TitleRotation () { 'xrtY2TitleRotation' }
sub XtNxrtYAnnoPlacement () { 'xrtYAnnoPlacement' }
sub XtNxrtYAnnotationAngle () { 'xrtYAnnotationAngle' }
sub XtNxrtYAnnotationAngleUseDefault () { 'xrtYAnnotationAngleUseDefault' }
sub XtNxrtYAnnotationMethod () { 'xrtYAnnotationMethod' }
sub XtNxrtYAnnotationRotation () { 'xrtYAnnotationRotation' }
sub XtNxrtYAxis100Percent () { 'xrtYAxis100Percent' }
sub XtNxrtYAxisConst () { 'xrtYAxisConst' }
sub XtNxrtYAxisLabelFormat () { 'xrtYAxisLabelFormat' }
sub XtNxrtYAxisLogarithmic () { 'xrtYAxisLogarithmic' }
sub XtNxrtYAxisMax () { 'xrtYAxisMax' }
sub XtNxrtYAxisMaxUseDefault () { 'xrtYAxisMaxUseDefault' }
sub XtNxrtYAxisMin () { 'xrtYAxisMin' }
sub XtNxrtYAxisMinUseDefault () { 'xrtYAxisMinUseDefault' }
sub XtNxrtYAxisMult () { 'xrtYAxisMult' }
sub XtNxrtYAxisReversed () { 'xrtYAxisReversed' }
sub XtNxrtYAxisShow () { 'xrtYAxisShow' }
sub XtNxrtYGrid () { 'xrtYGrid' }
sub XtNxrtYGridDataStyle () { 'xrtYGridDataStyle' }
sub XtNxrtYGridDataStyleUseDefault () { 'xrtYGridDataStyleUseDefault' }
sub XtNxrtYGridUseDefault () { 'xrtYGridUseDefault' }
sub XtNxrtYLabels () { 'xrtYLabels' }
sub XtNxrtYMarker () { 'xrtYMarker' }
sub XtNxrtYMarkerDataStyle () { 'xrtYMarkerDataStyle' }
sub XtNxrtYMarkerDataStyleUseDefault () { 'xrtYMarkerDataStyleUseDefault' }
sub XtNxrtYMarkerShow () { 'xrtYMarkerShow' }
sub XtNxrtYMax () { 'xrtYMax' }
sub XtNxrtYMaxUseDefault () { 'xrtYMaxUseDefault' }
sub XtNxrtYMin () { 'xrtYMin' }
sub XtNxrtYMinUseDefault () { 'xrtYMinUseDefault' }
sub XtNxrtYNum () { 'xrtYNum' }
sub XtNxrtYNumMethod () { 'xrtYNumMethod' }
sub XtNxrtYNumUseDefault () { 'xrtYNumUseDefault' }
sub XtNxrtYOrigin () { 'xrtYOrigin' }
sub XtNxrtYOriginPlacement () { 'xrtYOriginPlacement' }
sub XtNxrtYOriginUseDefault () { 'xrtYOriginUseDefault' }
sub XtNxrtYPrecision () { 'xrtYPrecision' }
sub XtNxrtYPrecisionUseDefault () { 'xrtYPrecisionUseDefault' }
sub XtNxrtYTick () { 'xrtYTick' }
sub XtNxrtYTickUseDefault () { 'xrtYTickUseDefault' }
sub XtNxrtYTitle () { 'xrtYTitle' }
sub XtNxrtYTitleRotation () { 'xrtYTitleRotation' }
sub XtNxrtZoomAxisCallback () { 'xrtZoomAxisCallback' }
1;
