package X11::MotifCons;
package X::Motif;
sub Xm1000TH_INCHES () { 2 }
sub Xm100TH_FONT_UNITS () { 4 }
sub Xm100TH_MILLIMETERS () { 1 }
sub Xm100TH_POINTS () { 3 }
sub XmALIGNMENT_BASELINE_BOTTOM () { 2 }
sub XmALIGNMENT_BASELINE_TOP () { 0 }
sub XmALIGNMENT_BEGINNING () { 0 }
sub XmALIGNMENT_CENTER () { 1 }
sub XmALIGNMENT_CONTENTS_BOTTOM () { 4 }
sub XmALIGNMENT_CONTENTS_TOP () { 3 }
sub XmALIGNMENT_END () { 2 }
sub XmALIGNMENT_WIDGET_BOTTOM () { 4 }
sub XmALIGNMENT_WIDGET_TOP () { 3 }
sub XmAPPLICATION_DEFINED () { 1 }
sub XmARROW_DOWN () { 1 }
sub XmARROW_LEFT () { 2 }
sub XmARROW_RIGHT () { 3 }
sub XmARROW_UP () { 0 }
sub XmAS_NEEDED () { 1 }
sub XmATTACH_FORM () { 1 }
sub XmATTACH_NONE () { 0 }
sub XmATTACH_OPPOSITE_FORM () { 2 }
sub XmATTACH_OPPOSITE_WIDGET () { 4 }
sub XmATTACH_POSITION () { 5 }
sub XmATTACH_SELF () { 6 }
sub XmATTACH_WIDGET () { 3 }
sub XmAUTOMATIC () { 0 }
sub XmBELL () { 1 }
sub XmBOTTOM_LEFT () { 2 }
sub XmBOTTOM_RIGHT () { 0 }
sub XmBROWSE_SELECT () { 3 }
sub XmCASCADEBUTTON () { 4 }
sub XmCHANGE_ALL () { 0 }
sub XmCHANGE_HEIGHT () { 3 }
sub XmCHANGE_NONE () { 1 }
sub XmCHANGE_WIDTH () { 2 }
sub XmCHECKBUTTON () { 2 }
sub XmCOMMAND_ABOVE_WORKSPACE () { 0 }
sub XmCOMMAND_BELOW_WORKSPACE () { 1 }
sub XmCONSTANT () { 1 }
sub XmCOPY_FAILED () { 0 }
sub XmCOPY_SUCCEEDED () { 1 }
sub XmCOPY_TRUNCATED () { 2 }
sub XmCR_ACTIVATE () { 10 }
sub XmCR_APPLY () { 34 }
sub XmCR_ARM () { 11 }
sub XmCR_BROWSE_SELECT () { 26 }
sub XmCR_CANCEL () { 32 }
sub XmCR_CASCADING () { 30 }
sub XmCR_CLIPBOARD_DATA_DELETE () { 29 }
sub XmCR_CLIPBOARD_DATA_REQUEST () { 28 }
sub XmCR_COMMAND_CHANGED () { 37 }
sub XmCR_COMMAND_ENTERED () { 36 }
sub XmCR_CREATE () { 43 }
sub XmCR_DECREMENT () { 4 }
sub XmCR_DEFAULT_ACTION () { 27 }
sub XmCR_DISARM () { 12 }
sub XmCR_DRAG () { 9 }
sub XmCR_EXECUTE () { 22 }
sub XmCR_EXPOSE () { 38 }
sub XmCR_EXTENDED_SELECT () { 25 }
sub XmCR_FOCUS () { 18 }
sub XmCR_GAIN_PRIMARY () { 41 }
sub XmCR_HELP () { 1 }
sub XmCR_INCREMENT () { 3 }
sub XmCR_INPUT () { 40 }
sub XmCR_LOSE_PRIMARY () { 42 }
sub XmCR_LOSING_FOCUS () { 19 }
sub XmCR_MAP () { 16 }
sub XmCR_MODIFYING_TEXT_VALUE () { 20 }
sub XmCR_MOVING_INSERT_CURSOR () { 21 }
sub XmCR_MULTIPLE_SELECT () { 24 }
sub XmCR_NONE () { 0 }
sub XmCR_NO_MATCH () { 35 }
sub XmCR_OBSCURED_TRAVERSAL () { 46 }
sub XmCR_OK () { 31 }
sub XmCR_PAGE_DECREMENT () { 6 }
sub XmCR_PAGE_INCREMENT () { 5 }
sub XmCR_PROTOCOLS () { 47 }
sub XmCR_RESIZE () { 39 }
sub XmCR_SINGLE_SELECT () { 23 }
sub XmCR_TEAR_OFF_ACTIVATE () { 44 }
sub XmCR_TEAR_OFF_DEACTIVATE () { 45 }
sub XmCR_TO_BOTTOM () { 8 }
sub XmCR_TO_TOP () { 7 }
sub XmCR_UNMAP () { 17 }
sub XmCR_VALUE_CHANGED () { 2 }
sub XmCURSOR () { 2 }
sub XmDEFAULT_DARK_THRESHOLD () { 15 }
sub XmDEFAULT_FOREGROUND_THRESHOLD () { 35 }
sub XmDEFAULT_LIGHT_THRESHOLD () { 77 }
sub XmDESTROY () { 0 }
sub XmDIALOG_APPLICATION_MODAL () { 1 }
sub XmDIALOG_APPLY_BUTTON () { 1 }
sub XmDIALOG_CANCEL_BUTTON () { 2 }
sub XmDIALOG_COMMAND () { 3 }
sub XmDIALOG_COMMAND_TEXT () { 13 }
sub XmDIALOG_DEFAULT_BUTTON () { 3 }
sub XmDIALOG_DIR_LIST () { 15 }
sub XmDIALOG_DIR_LIST_LABEL () { 16 }
sub XmDIALOG_ERROR () { 1 }
sub XmDIALOG_FILE_LIST () { 8 }
sub XmDIALOG_FILE_LIST_LABEL () { 9 }
sub XmDIALOG_FILE_SELECTION () { 4 }
sub XmDIALOG_FILTER_LABEL () { 5 }
sub XmDIALOG_FILTER_TEXT () { 6 }
sub XmDIALOG_FULL_APPLICATION_MODAL () { 2 }
sub XmDIALOG_HELP_BUTTON () { 7 }
sub XmDIALOG_HISTORY_LIST () { 8 }
sub XmDIALOG_INFORMATION () { 2 }
sub XmDIALOG_LIST () { 8 }
sub XmDIALOG_LIST_LABEL () { 9 }
sub XmDIALOG_MESSAGE () { 3 }
sub XmDIALOG_MESSAGE_LABEL () { 10 }
sub XmDIALOG_MODELESS () { 0 }
sub XmDIALOG_NONE () { 0 }
sub XmDIALOG_OK_BUTTON () { 4 }
sub XmDIALOG_PRIMARY_APPLICATION_MODAL () { 1 }
sub XmDIALOG_PROMPT () { 1 }
sub XmDIALOG_PROMPT_LABEL () { 11 }
sub XmDIALOG_QUESTION () { 4 }
sub XmDIALOG_SELECTION () { 2 }
sub XmDIALOG_SELECTION_LABEL () { 11 }
sub XmDIALOG_SEPARATOR () { 14 }
sub XmDIALOG_SYMBOL_LABEL () { 12 }
sub XmDIALOG_SYSTEM_MODAL () { 3 }
sub XmDIALOG_TEMPLATE () { 0 }
sub XmDIALOG_TEXT () { 13 }
sub XmDIALOG_VALUE_TEXT () { 13 }
sub XmDIALOG_WARNING () { 5 }
sub XmDIALOG_WORKING () { 6 }
sub XmDIALOG_WORK_AREA () { 0 }
sub XmDOUBLE_DASHED_LINE () { 4 }
sub XmDOUBLE_LINE () { 2 }
sub XmDOUBLE_SEPARATOR () { 6 }
sub XmDO_NOTHING () { 2 }
sub XmDYNAMIC () { 1 }
sub XmDYNAMIC_DEFAULT_TAB_GROUP () { 255 }
sub XmEXCLUSIVE_TAB_GROUP () { 3 }
sub XmEXPLICIT () { 0 }
sub XmEXTENDED_SELECT () { 2 }
sub XmFILE_ANY_TYPE () { 3 }
sub XmFILE_DIRECTORY () { 1 }
sub XmFILE_REGULAR () { 2 }
sub XmFIRST_POSITION () { 0 }
sub XmFMT_16_BIT () { 2 }
sub XmFMT_8_BIT () { 31 }
sub XmFONT_IS_FONT () { 0 }
sub XmFONT_IS_FONTSET () { 1 }
sub XmFRAME_GENERIC_CHILD () { 0 }
sub XmFRAME_TITLE_CHILD () { 2 }
sub XmFRAME_WORKAREA_CHILD () { 1 }
sub XmHIGHLIGHT_NORMAL () { 0 }
sub XmHIGHLIGHT_SECONDARY_SELECTED () { 2 }
sub XmHIGHLIGHT_SELECTED () { 1 }
sub XmHORIZONTAL () { 2 }
sub XmINVALID_SEPARATOR_TYPE () { 9 }
sub XmLAST_POSITION () { -1 }
sub XmMAX_ON_BOTTOM () { 1 }
sub XmMAX_ON_LEFT () { 2 }
sub XmMAX_ON_RIGHT () { 3 }
sub XmMAX_ON_TOP () { 0 }
sub XmMENU_BAR () { 1 }
sub XmMENU_OPTION () { 4 }
sub XmMENU_POPUP () { 3 }
sub XmMENU_PULLDOWN () { 2 }
sub XmMULTICLICK_DISCARD () { 0 }
sub XmMULTICLICK_KEEP () { 1 }
sub XmMULTIPLE_SELECT () { 1 }
sub XmMULTI_LINE_EDIT () { 0 }
sub XmNONE () { 0 }
sub XmNO_LINE () { 0 }
sub XmNO_ORIENTATION () { 0 }
sub XmNO_PACKING () { 0 }
sub XmN_OF_MANY () { 1 }
sub XmONE_OF_MANY () { 2 }
sub XmPACK_COLUMN () { 2 }
sub XmPACK_NONE () { 3 }
sub XmPACK_TIGHT () { 1 }
sub XmPIXELS () { 0 }
sub XmPIXMAP () { 1 }
sub XmPLACE_ABOVE_SELECTION () { 1 }
sub XmPLACE_BELOW_SELECTION () { 2 }
sub XmPLACE_TOP () { 0 }
sub XmPOINTER () { 1 }
sub XmPUSHBUTTON () { 1 }
sub XmRADIOBUTTON () { 3 }
sub XmRESIZE_ANY () { 2 }
sub XmRESIZE_GROW () { 1 }
sub XmRESIZE_IF_POSSIBLE () { 2 }
sub XmRESIZE_NONE () { 0 }
sub XmREVISION () { 2 }
sub XmSELECT_ALL () { 4 }
sub XmSELECT_LINE () { 3 }
sub XmSELECT_PARAGRAPH () { 5 }
sub XmSELECT_POSITION () { 0 }
sub XmSELECT_WHITESPACE () { 1 }
sub XmSELECT_WORD () { 2 }
sub XmSEPARATOR () { 5 }
sub XmSHADOW_ETCHED_IN () { 5 }
sub XmSHADOW_ETCHED_IN_DASH () { 7 }
sub XmSHADOW_ETCHED_OUT () { 6 }
sub XmSHADOW_ETCHED_OUT_DASH () { 8 }
sub XmSHADOW_IN () { 7 }
sub XmSHADOW_OUT () { 8 }
sub XmSINGLE_DASHED_LINE () { 3 }
sub XmSINGLE_LINE () { 1 }
sub XmSINGLE_LINE_EDIT () { 1 }
sub XmSINGLE_SELECT () { 0 }
sub XmSTATIC () { 0 }
sub XmSTICKY_TAB_GROUP () { 2 }
sub XmSTRING () { 2 }
sub XmSTRING_COMPONENT_CHARSET () { 1 }
sub XmSTRING_COMPONENT_DIRECTION () { 3 }
sub XmSTRING_COMPONENT_END () { 126 }
sub XmSTRING_COMPONENT_LOCALE_TEXT () { 5 }
sub XmSTRING_COMPONENT_SEPARATOR () { 4 }
sub XmSTRING_COMPONENT_TEXT () { 2 }
sub XmSTRING_COMPONENT_UNKNOWN () { 0 }
sub XmSTRING_COMPONENT_USER_BEGIN () { 128 }
sub XmSTRING_COMPONENT_USER_END () { 255 }
sub XmSTRING_DIRECTION_DEFAULT () { 255 }
sub XmSTRING_DIRECTION_L_TO_R () { 0 }
sub XmSTRING_DIRECTION_R_TO_L () { 1 }
sub XmTAB_GROUP () { 1 }
sub XmTEAR_OFF_DISABLED () { 1 }
sub XmTEAR_OFF_ENABLED () { 0 }
sub XmTEXT_BACKWARD () { 1 }
sub XmTEXT_FORWARD () { 0 }
sub XmTITLE () { 7 }
sub XmTOGGLEBUTTON () { 2 }
sub XmTOP_LEFT () { 3 }
sub XmTOP_RIGHT () { 1 }
sub XmTRAVERSE_CURRENT () { 0 }
sub XmTRAVERSE_DOWN () { 7 }
sub XmTRAVERSE_HOME () { 3 }
sub XmTRAVERSE_LEFT () { 8 }
sub XmTRAVERSE_NEXT () { 1 }
sub XmTRAVERSE_NEXT_TAB_GROUP () { 4 }
sub XmTRAVERSE_PREV () { 2 }
sub XmTRAVERSE_PREV_TAB_GROUP () { 5 }
sub XmTRAVERSE_RIGHT () { 9 }
sub XmTRAVERSE_UP () { 6 }
sub XmUNMAP () { 1 }
sub XmUNPOST () { 0 }
sub XmUNPOST_AND_REPLAY () { 1 }
sub XmUNSPECIFIED_PIXMAP () { 2 }
sub XmUPDATE_LEVEL () { 3 }
sub XmVARIABLE () { 0 }
sub XmVERSION () { 1 }
sub XmVERTICAL () { 1 }
sub XmVISIBILITY_FULLY_OBSCURED () { 2 }
sub XmVISIBILITY_PARTIALLY_OBSCURED () { 1 }
sub XmVISIBILITY_UNOBSCURED () { 0 }
sub XmVersion () { 1002 }
sub XmWINDOW () { 0 }
sub XmWORK_AREA () { 0 }
sub XmDEFAULT_BACKGROUND () { '#729FFF' }
sub XmDEFAULT_FONT () { 'fixed' }
sub XmFALLBACK_CHARSET () { 'ISO8859-1' }
sub XmSTRING_OS_CHARSET () { 'ISO8859-1' }
sub XmVERSION_STRING () { '@(#)OSF/Motif Version 1.2.3' }
sub XmNaccelerator () { 'accelerator' }
sub XmNacceleratorText () { 'acceleratorText' }
sub XmNaccelerators () { 'accelerators' }
sub XmNactivateCallback () { 'activateCallback' }
sub XmNadjustLast () { 'adjustLast' }
sub XmNadjustMargin () { 'adjustMargin' }
sub XmNalignment () { 'alignment' }
sub XmNallowOverlap () { 'allowOverlap' }
sub XmNallowResize () { 'allowResize' }
sub XmNallowShellResize () { 'allowShellResize' }
sub XmNancestorSensitive () { 'ancestorSensitive' }
sub XmNanimationMask () { 'animationMask' }
sub XmNanimationPixmap () { 'animationPixmap' }
sub XmNanimationPixmapDepth () { 'animationPixmapDepth' }
sub XmNanimationStyle () { 'animationStyle' }
sub XmNapplyCallback () { 'applyCallback' }
sub XmNapplyLabelString () { 'applyLabelString' }
sub XmNargc () { 'argc' }
sub XmNargv () { 'argv' }
sub XmNarmCallback () { 'armCallback' }
sub XmNarmColor () { 'armColor' }
sub XmNarmPixmap () { 'armPixmap' }
sub XmNarrowDirection () { 'arrowDirection' }
sub XmNattachment () { 'attachment' }
sub XmNaudibleWarning () { 'audibleWarning' }
sub XmNautoShowCursorPosition () { 'autoShowCursorPosition' }
sub XmNautoUnmanage () { 'autoUnmanage' }
sub XmNautomaticSelection () { 'automaticSelection' }
sub XmNavailability () { 'availability' }
sub XmNbackground () { 'background' }
sub XmNbackgroundPixmap () { 'backgroundPixmap' }
sub XmNbaseHeight () { 'baseHeight' }
sub XmNbaseWidth () { 'baseWidth' }
sub XmNbitmap () { 'bitmap' }
sub XmNblendModel () { 'blendModel' }
sub XmNblinkRate () { 'blinkRate' }
sub XmNborder () { 'borderColor' }
sub XmNborderColor () { 'borderColor' }
sub XmNborderPixmap () { 'borderPixmap' }
sub XmNborderWidth () { 'borderWidth' }
sub XmNbottomAttachment () { 'bottomAttachment' }
sub XmNbottomOffset () { 'bottomOffset' }
sub XmNbottomPosition () { 'bottomPosition' }
sub XmNbottomShadowColor () { 'bottomShadowColor' }
sub XmNbottomShadowPixmap () { 'bottomShadowPixmap' }
sub XmNbottomWidget () { 'bottomWidget' }
sub XmNbrowseSelectionCallback () { 'browseSelectionCallback' }
sub XmNbuttonAcceleratorText () { 'buttonAcceleratorText' }
sub XmNbuttonAccelerators () { 'buttonAccelerators' }
sub XmNbuttonCount () { 'buttonCount' }
sub XmNbuttonFontList () { 'buttonFontList' }
sub XmNbuttonMnemonicCharSets () { 'buttonMnemonicCharSets' }
sub XmNbuttonMnemonics () { 'buttonMnemonics' }
sub XmNbuttonSet () { 'buttonSet' }
sub XmNbuttonType () { 'buttonType' }
sub XmNbuttons () { 'buttons' }
sub XmNcallback () { 'callback' }
sub XmNcancelButton () { 'cancelButton' }
sub XmNcancelCallback () { 'cancelCallback' }
sub XmNcancelLabelString () { 'cancelLabelString' }
sub XmNcascadePixmap () { 'cascadePixmap' }
sub XmNcascadingCallback () { 'cascadingCallback' }
sub XmNchildHorizontalAlignment () { 'childHorizontalAlignment' }
sub XmNchildHorizontalSpacing () { 'childHorizontalSpacing' }
sub XmNchildPlacement () { 'childPlacement' }
sub XmNchildPosition () { 'childPosition' }
sub XmNchildType () { 'childType' }
sub XmNchildVerticalAlignment () { 'childVerticalAlignment' }
sub XmNchildren () { 'children' }
sub XmNclientData () { 'clientData' }
sub XmNclipWindow () { 'clipWindow' }
sub XmNcolormap () { 'colormap' }
sub XmNcolumns () { 'columns' }
sub XmNcommand () { 'command' }
sub XmNcommandChangedCallback () { 'commandChangedCallback' }
sub XmNcommandEnteredCallback () { 'commandEnteredCallback' }
sub XmNcommandWindow () { 'commandWindow' }
sub XmNcommandWindowLocation () { 'commandWindowLocation' }
sub XmNconvertProc () { 'convertProc' }
sub XmNcreatePopupChildProc () { 'createPopupChildProc' }
sub XmNcursorBackground () { 'cursorBackground' }
sub XmNcursorForeground () { 'cursorForeground' }
sub XmNcursorPosition () { 'cursorPosition' }
sub XmNcursorPositionVisible () { 'cursorPositionVisible' }
sub XmNdarkThreshold () { 'darkThreshold' }
sub XmNdecimalPoints () { 'decimalPoints' }
sub XmNdecrementCallback () { 'decrementCallback' }
sub XmNdefaultActionCallback () { 'defaultActionCallback' }
sub XmNdefaultButton () { 'defaultButton' }
sub XmNdefaultButtonShadowThickness () { 'defaultButtonShadowThickness' }
sub XmNdefaultButtonType () { 'defaultButtonType' }
sub XmNdefaultCopyCursorIcon () { 'defaultCopyCursorIcon' }
sub XmNdefaultFontList () { 'defaultFontList' }
sub XmNdefaultInvalidCursorIcon () { 'defaultInvalidCursorIcon' }
sub XmNdefaultLinkCursorIcon () { 'defaultLinkCursorIcon' }
sub XmNdefaultMoveCursorIcon () { 'defaultMoveCursorIcon' }
sub XmNdefaultNoneCursorIcon () { 'defaultNoneCursorIcon' }
sub XmNdefaultPosition () { 'defaultPosition' }
sub XmNdefaultSourceCursorIcon () { 'defaultSourceCursorIcon' }
sub XmNdefaultValidCursorIcon () { 'defaultValidCursorIcon' }
sub XmNdeleteResponse () { 'deleteResponse' }
sub XmNdepth () { 'depth' }
sub XmNdesktopParent () { 'desktopParent' }
sub XmNdestroyCallback () { 'destroyCallback' }
sub XmNdialogStyle () { 'dialogStyle' }
sub XmNdialogTitle () { 'dialogTitle' }
sub XmNdialogType () { 'dialogType' }
sub XmNdirListItemCount () { 'dirListItemCount' }
sub XmNdirListItems () { 'dirListItems' }
sub XmNdirListLabelString () { 'dirListLabelString' }
sub XmNdirMask () { 'dirMask' }
sub XmNdirSearchProc () { 'dirSearchProc' }
sub XmNdirSpec () { 'dirSpec' }
sub XmNdirectory () { 'directory' }
sub XmNdirectoryValid () { 'directoryValid' }
sub XmNdisarmCallback () { 'disarmCallback' }
sub XmNdoubleClickInterval () { 'doubleClickInterval' }
sub XmNdragCallback () { 'dragCallback' }
sub XmNdragContextClass () { 'dragContextClass' }
sub XmNdragDropFinishCallback () { 'dragDropFinishCallback' }
sub XmNdragIconClass () { 'dragIconClass' }
sub XmNdragInitiatorProtocolStyle () { 'dragInitiatorProtocolStyle' }
sub XmNdragMotionCallback () { 'dragMotionCallback' }
sub XmNdragOperations () { 'dragOperations' }
sub XmNdragOverMode () { 'dragOverMode' }
sub XmNdragProc () { 'dragProc' }
sub XmNdragReceiverProtocolStyle () { 'dragReceiverProtocolStyle' }
sub XmNdropFinishCallback () { 'dropFinishCallback' }
sub XmNdropProc () { 'dropProc' }
sub XmNdropRectangles () { 'dropRectangles' }
sub XmNdropSiteActivity () { 'dropSiteActivity' }
sub XmNdropSiteEnterCallback () { 'dropSiteEnterCallback' }
sub XmNdropSiteLeaveCallback () { 'dropSiteLeaveCallback' }
sub XmNdropSiteManagerClass () { 'dropSiteManagerClass' }
sub XmNdropSiteOperations () { 'dropSiteOperations' }
sub XmNdropSiteType () { 'dropSiteType' }
sub XmNdropStartCallback () { 'dropStartCallback' }
sub XmNdropTransferClass () { 'dropTransferClass' }
sub XmNdropTransfers () { 'dropTransfers' }
sub XmNeditMode () { 'editMode' }
sub XmNeditType () { 'editType' }
sub XmNeditable () { 'editable' }
sub XmNentryAlignment () { 'entryAlignment' }
sub XmNentryBorder () { 'entryBorder' }
sub XmNentryCallback () { 'entryCallback' }
sub XmNentryClass () { 'entryClass' }
sub XmNentryVerticalAlignment () { 'entryVerticalAlignment' }
sub XmNexportTargets () { 'exportTargets' }
sub XmNexposeCallback () { 'exposeCallback' }
sub XmNextendedSelectionCallback () { 'extendedSelectionCallback' }
sub XmNextensionType () { 'extensionType' }
sub XmNfile () { 'file' }
sub XmNfileListItemCount () { 'fileListItemCount' }
sub XmNfileListItems () { 'fileListItems' }
sub XmNfileListLabelString () { 'fileListLabelString' }
sub XmNfileSearchProc () { 'fileSearchProc' }
sub XmNfileTypeMask () { 'fileTypeMask' }
sub XmNfillOnArm () { 'fillOnArm' }
sub XmNfillOnSelect () { 'fillOnSelect' }
sub XmNfilterLabelString () { 'filterLabelString' }
sub XmNfocusCallback () { 'focusCallback' }
sub XmNfocusMovedCallback () { 'focusMovedCallback' }
sub XmNfocusPolicyChanged () { 'focusPolicyChanged' }
sub XmNfont () { 'font' }
sub XmNfontList () { 'fontList' }
sub XmNfontSet () { 'fontSet' }
sub XmNforceBars () { 'forceBars' }
sub XmNforeground () { 'foreground' }
sub XmNforegroundThreshold () { 'foregroundThreshold' }
sub XmNfractionBase () { 'fractionBase' }
sub XmNfunction () { 'function' }
sub XmNgainPrimaryCallback () { 'gainPrimaryCallback' }
sub XmNgeometry () { 'geometry' }
sub XmNheight () { 'height' }
sub XmNheightInc () { 'heightInc' }
sub XmNhelpCallback () { 'helpCallback' }
sub XmNhelpLabelString () { 'helpLabelString' }
sub XmNhighlight () { 'highlight' }
sub XmNhighlightColor () { 'highlightColor' }
sub XmNhighlightOnEnter () { 'highlightOnEnter' }
sub XmNhighlightPixmap () { 'highlightPixmap' }
sub XmNhighlightThickness () { 'highlightThickness' }
sub XmNhistoryItemCount () { 'historyItemCount' }
sub XmNhistoryItems () { 'historyItems' }
sub XmNhistoryMaxItems () { 'historyMaxItems' }
sub XmNhistoryVisibleItemCount () { 'historyVisibleItemCount' }
sub XmNhorizontalFontUnit () { 'horizontalFontUnit' }
sub XmNhorizontalScrollBar () { 'horizontalScrollBar' }
sub XmNhorizontalSpacing () { 'horizontalSpacing' }
sub XmNhotX () { 'hotX' }
sub XmNhotY () { 'hotY' }
sub XmNiccHandle () { 'iccHandle' }
sub XmNiconMask () { 'iconMask' }
sub XmNiconName () { 'iconName' }
sub XmNiconNameEncoding () { 'iconNameEncoding' }
sub XmNiconPixmap () { 'iconPixmap' }
sub XmNiconWindow () { 'iconWindow' }
sub XmNiconX () { 'iconX' }
sub XmNiconY () { 'iconY' }
sub XmNiconic () { 'iconic' }
sub XmNimportTargets () { 'importTargets' }
sub XmNincrement () { 'increment' }
sub XmNincrementCallback () { 'incrementCallback' }
sub XmNincremental () { 'incremental' }
sub XmNindex () { 'index' }
sub XmNindicatorOn () { 'indicatorOn' }
sub XmNindicatorSize () { 'indicatorSize' }
sub XmNindicatorType () { 'indicatorType' }
sub XmNinitialDelay () { 'initialDelay' }
sub XmNinitialFocus () { 'initialFocus' }
sub XmNinitialResourcesPersistent () { 'initialResourcesPersistent' }
sub XmNinitialState () { 'initialState' }
sub XmNinnerHeight () { 'innerHeight' }
sub XmNinnerWidth () { 'innerWidth' }
sub XmNinnerWindow () { 'innerWindow' }
sub XmNinput () { 'input' }
sub XmNinputCallback () { 'inputCallback' }
sub XmNinputCreate () { 'inputCreate' }
sub XmNinputMethod () { 'inputMethod' }
sub XmNinsertPosition () { 'insertPosition' }
sub XmNinternalHeight () { 'internalHeight' }
sub XmNinternalWidth () { 'internalWidth' }
sub XmNinvalidCursorForeground () { 'invalidCursorForeground' }
sub XmNisAligned () { 'isAligned' }
sub XmNisHomogeneous () { 'isHomogeneous' }
sub XmNitemCount () { 'itemCount' }
sub XmNitems () { 'items' }
sub XmNjumpProc () { 'jumpProc' }
sub XmNjustify () { 'justify' }
sub XmNkeyboardFocusPolicy () { 'keyboardFocusPolicy' }
sub XmNlabelFontList () { 'labelFontList' }
sub XmNlabelInsensitivePixmap () { 'labelInsensitivePixmap' }
sub XmNlabelPixmap () { 'labelPixmap' }
sub XmNlabelString () { 'labelString' }
sub XmNlabelType () { 'labelType' }
sub XmNleftAttachment () { 'leftAttachment' }
sub XmNleftOffset () { 'leftOffset' }
sub XmNleftPosition () { 'leftPosition' }
sub XmNleftWidget () { 'leftWidget' }
sub XmNlength () { 'length' }
sub XmNlightThreshold () { 'lightThreshold' }
sub XmNlineSpace () { 'lineSpace' }
sub XmNlistItemCount () { 'listItemCount' }
sub XmNlistItems () { 'listItems' }
sub XmNlistLabelString () { 'listLabelString' }
sub XmNlistMarginHeight () { 'listMarginHeight' }
sub XmNlistMarginWidth () { 'listMarginWidth' }
sub XmNlistSizePolicy () { 'listSizePolicy' }
sub XmNlistSpacing () { 'listSpacing' }
sub XmNlistUpdated () { 'listUpdated' }
sub XmNlistVisibleItemCount () { 'listVisibleItemCount' }
sub XmNlogicalParent () { 'logicalParent' }
sub XmNlosePrimaryCallback () { 'losePrimaryCallback' }
sub XmNlosingFocusCallback () { 'losingFocusCallback' }
sub XmNlowerRight () { 'lowerRight' }
sub XmNmainWindowMarginHeight () { 'mainWindowMarginHeight' }
sub XmNmainWindowMarginWidth () { 'mainWindowMarginWidth' }
sub XmNmapCallback () { 'mapCallback' }
sub XmNmappedWhenManaged () { 'mappedWhenManaged' }
sub XmNmappingDelay () { 'mappingDelay' }
sub XmNmargin () { 'margin' }
sub XmNmarginBottom () { 'marginBottom' }
sub XmNmarginHeight () { 'marginHeight' }
sub XmNmarginLeft () { 'marginLeft' }
sub XmNmarginRight () { 'marginRight' }
sub XmNmarginTop () { 'marginTop' }
sub XmNmarginWidth () { 'marginWidth' }
sub XmNmask () { 'mask' }
sub XmNmaxAspectX () { 'maxAspectX' }
sub XmNmaxAspectY () { 'maxAspectY' }
sub XmNmaxHeight () { 'maxHeight' }
sub XmNmaxLength () { 'maxLength' }
sub XmNmaxWidth () { 'maxWidth' }
sub XmNmaximum () { 'maximum' }
sub XmNmenuAccelerator () { 'menuAccelerator' }
sub XmNmenuBar () { 'menuBar' }
sub XmNmenuCursor () { 'menuCursor' }
sub XmNmenuEntry () { 'menuEntry' }
sub XmNmenuHelpWidget () { 'menuHelpWidget' }
sub XmNmenuHistory () { 'menuHistory' }
sub XmNmenuPost () { 'menuPost' }
sub XmNmessageAlignment () { 'messageAlignment' }
sub XmNmessageProc () { 'messageProc' }
sub XmNmessageString () { 'messageString' }
sub XmNmessageWindow () { 'messageWindow' }
sub XmNminAspectX () { 'minAspectX' }
sub XmNminAspectY () { 'minAspectY' }
sub XmNminHeight () { 'minHeight' }
sub XmNminWidth () { 'minWidth' }
sub XmNminimizeButtons () { 'minimizeButtons' }
sub XmNminimum () { 'minimum' }
sub XmNmnemonic () { 'mnemonic' }
sub XmNmnemonicCharSet () { 'mnemonicCharSet' }
sub XmNmodifyVerifyCallback () { 'modifyVerifyCallback' }
sub XmNmodifyVerifyCallbackWcs () { 'modifyVerifyCallbackWcs' }
sub XmNmotionVerifyCallback () { 'motionVerifyCallback' }
sub XmNmoveOpaque () { 'moveOpaque' }
sub XmNmultiClick () { 'multiClick' }
sub XmNmultipleSelectionCallback () { 'multipleSelectionCallback' }
sub XmNmustMatch () { 'mustMatch' }
sub XmNmwmDecorations () { 'mwmDecorations' }
sub XmNmwmFunctions () { 'mwmFunctions' }
sub XmNmwmInputMode () { 'mwmInputMode' }
sub XmNmwmMenu () { 'mwmMenu' }
sub XmNmwmMessages () { 'mwmMessages' }
sub XmNname () { 'name' }
sub XmNnavigationType () { 'navigationType' }
sub XmNneedsMotion () { 'needsMotion' }
sub XmNnoMatchCallback () { 'noMatchCallback' }
sub XmNnoMatchString () { 'noMatchString' }
sub XmNnoResize () { 'noResize' }
sub XmNnoneCursorForeground () { 'noneCursorForeground' }
sub XmNnotify () { 'notify' }
sub XmNnotifyProc () { 'notifyProc' }
sub XmNnumChildren () { 'numChildren' }
sub XmNnumColumns () { 'numColumns' }
sub XmNnumDropRectangles () { 'numDropRectangles' }
sub XmNnumDropTransfers () { 'numDropTransfers' }
sub XmNnumExportTargets () { 'numExportTargets' }
sub XmNnumImportTargets () { 'numImportTargets' }
sub XmNnumRectangles () { 'numRectangles' }
sub XmNoffsetX () { 'offsetX' }
sub XmNoffsetY () { 'offsetY' }
sub XmNokCallback () { 'okCallback' }
sub XmNokLabelString () { 'okLabelString' }
sub XmNoperationChangedCallback () { 'operationChangedCallback' }
sub XmNoperationCursorIcon () { 'operationCursorIcon' }
sub XmNoptionLabel () { 'optionLabel' }
sub XmNoptionMnemonic () { 'optionMnemonic' }
sub XmNorientation () { 'orientation' }
sub XmNoutputCreate () { 'outputCreate' }
sub XmNoverrideRedirect () { 'overrideRedirect' }
sub XmNpacking () { 'packing' }
sub XmNpageDecrementCallback () { 'pageDecrementCallback' }
sub XmNpageIncrement () { 'pageIncrement' }
sub XmNpageIncrementCallback () { 'pageIncrementCallback' }
sub XmNpaneMaximum () { 'paneMaximum' }
sub XmNpaneMinimum () { 'paneMinimum' }
sub XmNparameter () { 'parameter' }
sub XmNpattern () { 'pattern' }
sub XmNpendingDelete () { 'pendingDelete' }
sub XmNpixmap () { 'pixmap' }
sub XmNpopdownCallback () { 'popdownCallback' }
sub XmNpopupCallback () { 'popupCallback' }
sub XmNpopupEnabled () { 'popupEnabled' }
sub XmNpositionIndex () { 'positionIndex' }
sub XmNpostFromButton () { 'postFromButton' }
sub XmNpostFromCount () { 'postFromCount' }
sub XmNpostFromList () { 'postFromList' }
sub XmNpreeditType () { 'preeditType' }
sub XmNprocessingDirection () { 'processingDirection' }
sub XmNpromptString () { 'promptString' }
sub XmNprotocolCallback () { 'protocolCallback' }
sub XmNpushButtonEnabled () { 'pushButtonEnabled' }
sub XmNqualifySearchDataProc () { 'qualifySearchDataProc' }
sub XmNradioAlwaysOne () { 'radioAlwaysOne' }
sub XmNradioBehavior () { 'radioBehavior' }
sub XmNrealizeCallback () { 'realizeCallback' }
sub XmNrecomputeSize () { 'recomputeSize' }
sub XmNrectangles () { 'rectangles' }
sub XmNrefigureMode () { 'refigureMode' }
sub XmNrepeatDelay () { 'repeatDelay' }
sub XmNresizable () { 'resizable' }
sub XmNresize () { 'resize' }
sub XmNresizeCallback () { 'resizeCallback' }
sub XmNresizeHeight () { 'resizeHeight' }
sub XmNresizePolicy () { 'resizePolicy' }
sub XmNresizeWidth () { 'resizeWidth' }
sub XmNreverseVideo () { 'reverseVideo' }
sub XmNrightAttachment () { 'rightAttachment' }
sub XmNrightOffset () { 'rightOffset' }
sub XmNrightPosition () { 'rightPosition' }
sub XmNrightWidget () { 'rightWidget' }
sub XmNrowColumnType () { 'rowColumnType' }
sub XmNrows () { 'rows' }
sub XmNrubberPositioning () { 'rubberPositioning' }
sub XmNsashHeight () { 'sashHeight' }
sub XmNsashIndent () { 'sashIndent' }
sub XmNsashShadowThickness () { 'sashShadowThickness' }
sub XmNsashWidth () { 'sashWidth' }
sub XmNsaveUnder () { 'saveUnder' }
sub XmNscaleHeight () { 'scaleHeight' }
sub XmNscaleMultiple () { 'scaleMultiple' }
sub XmNscaleWidth () { 'scaleWidth' }
sub XmNscreen () { 'screen' }
sub XmNscrollBarDisplayPolicy () { 'scrollBarDisplayPolicy' }
sub XmNscrollBarPlacement () { 'scrollBarPlacement' }
sub XmNscrollDCursor () { 'scrollDCursor' }
sub XmNscrollHCursor () { 'scrollHCursor' }
sub XmNscrollHorizontal () { 'scrollHorizontal' }
sub XmNscrollLCursor () { 'scrollLCursor' }
sub XmNscrollLeftSide () { 'scrollLeftSide' }
sub XmNscrollProc () { 'scrollProc' }
sub XmNscrollRCursor () { 'scrollRCursor' }
sub XmNscrollTopSide () { 'scrollTopSide' }
sub XmNscrollUCursor () { 'scrollUCursor' }
sub XmNscrollVCursor () { 'scrollVCursor' }
sub XmNscrollVertical () { 'scrollVertical' }
sub XmNscrolledWindowMarginHeight () { 'scrolledWindowMarginHeight' }
sub XmNscrolledWindowMarginWidth () { 'scrolledWindowMarginWidth' }
sub XmNscrollingPolicy () { 'scrollingPolicy' }
sub XmNselectColor () { 'selectColor' }
sub XmNselectInsensitivePixmap () { 'selectInsensitivePixmap' }
sub XmNselectPixmap () { 'selectPixmap' }
sub XmNselectThreshold () { 'selectThreshold' }
sub XmNselectedItemCount () { 'selectedItemCount' }
sub XmNselectedItems () { 'selectedItems' }
sub XmNselection () { 'selection' }
sub XmNselectionArray () { 'selectionArray' }
sub XmNselectionArrayCount () { 'selectionArrayCount' }
sub XmNselectionLabelString () { 'selectionLabelString' }
sub XmNselectionPolicy () { 'selectionPolicy' }
sub XmNsensitive () { 'sensitive' }
sub XmNseparatorOn () { 'separatorOn' }
sub XmNseparatorType () { 'separatorType' }
sub XmNset () { 'set' }
sub XmNshadow () { 'shadow' }
sub XmNshadowThickness () { 'shadowThickness' }
sub XmNshadowType () { 'shadowType' }
sub XmNshellUnitType () { 'shellUnitType' }
sub XmNshowArrows () { 'showArrows' }
sub XmNshowAsDefault () { 'showAsDefault' }
sub XmNshowSeparator () { 'showSeparator' }
sub XmNshowValue () { 'showValue' }
sub XmNshown () { 'shown' }
sub XmNsimpleCallback () { 'simpleCallback' }
sub XmNsingleSelectionCallback () { 'singleSelectionCallback' }
sub XmNsizePolicy () { 'sizePolicy' }
sub XmNskipAdjust () { 'skipAdjust' }
sub XmNsliderSize () { 'sliderSize' }
sub XmNsource () { 'source' }
sub XmNsourceCursorIcon () { 'sourceCursorIcon' }
sub XmNsourceIsExternal () { 'sourceIsExternal' }
sub XmNsourcePixmapIcon () { 'sourcePixmapIcon' }
sub XmNsourceWidget () { 'sourceWidget' }
sub XmNsourceWindow () { 'sourceWindow' }
sub XmNspace () { 'space' }
sub XmNspacing () { 'spacing' }
sub XmNspotLocation () { 'spotLocation' }
sub XmNstartTime () { 'startTime' }
sub XmNstateCursorIcon () { 'stateCursorIcon' }
sub XmNstring () { 'string' }
sub XmNstringDirection () { 'stringDirection' }
sub XmNsubMenuId () { 'subMenuId' }
sub XmNsymbolPixmap () { 'symbolPixmap' }
sub XmNtearOffMenuActivateCallback () { 'tearOffMenuActivateCallback' }
sub XmNtearOffMenuDeactivateCallback () { 'tearOffMenuDeactivateCallback' }
sub XmNtearOffModel () { 'tearOffModel' }
sub XmNtextAccelerators () { 'textAccelerators' }
sub XmNtextColumns () { 'textColumns' }
sub XmNtextFontList () { 'textFontList' }
sub XmNtextOptions () { 'textOptions' }
sub XmNtextSink () { 'textSink' }
sub XmNtextSource () { 'textSource' }
sub XmNtextString () { 'textString' }
sub XmNtextTranslations () { 'textTranslations' }
sub XmNtextValue () { 'textValue' }
sub XmNthickness () { 'thickness' }
sub XmNthumb () { 'thumb' }
sub XmNthumbProc () { 'thumbProc' }
sub XmNtitle () { 'title' }
sub XmNtitleEncoding () { 'titleEncoding' }
sub XmNtitleString () { 'titleString' }
sub XmNtoBottomCallback () { 'toBottomCallback' }
sub XmNtoPositionCallback () { 'toPositionCallback' }
sub XmNtoTopCallback () { 'toTopCallback' }
sub XmNtop () { 'top' }
sub XmNtopAttachment () { 'topAttachment' }
sub XmNtopCharacter () { 'topCharacter' }
sub XmNtopItemPosition () { 'topItemPosition' }
sub XmNtopLevelEnterCallback () { 'topLevelEnterCallback' }
sub XmNtopLevelLeaveCallback () { 'topLevelLeaveCallback' }
sub XmNtopOffset () { 'topOffset' }
sub XmNtopPosition () { 'topPosition' }
sub XmNtopShadowColor () { 'topShadowColor' }
sub XmNtopShadowPixmap () { 'topShadowPixmap' }
sub XmNtopWidget () { 'topWidget' }
sub XmNtransferProc () { 'transferProc' }
sub XmNtransferStatus () { 'transferStatus' }
sub XmNtransient () { 'transient' }
sub XmNtransientFor () { 'transientFor' }
sub XmNtranslations () { 'translations' }
sub XmNtraversalCallback () { 'traversalCallback' }
sub XmNtraversalOn () { 'traversalOn' }
sub XmNtraversalType () { 'traversalType' }
sub XmNtraverseObscuredCallback () { 'traverseObscuredCallback' }
sub XmNtreeUpdateProc () { 'treeUpdateProc' }
sub XmNtroughColor () { 'troughColor' }
sub XmNunitType () { 'unitType' }
sub XmNunmapCallback () { 'unmapCallback' }
sub XmNunpostBehavior () { 'unpostBehavior' }
sub XmNunselectPixmap () { 'unselectPixmap' }
sub XmNupdate () { 'update' }
sub XmNupdateSliderSize () { 'updateSliderSize' }
sub XmNuseAsyncGeometry () { 'useAsyncGeometry' }
sub XmNuseBottom () { 'useBottom' }
sub XmNuseRight () { 'useRight' }
sub XmNuserData () { 'userData' }
sub XmNvalidCursorForeground () { 'validCursorForeground' }
sub XmNvalue () { 'value' }
sub XmNvalueChangedCallback () { 'valueChangedCallback' }
sub XmNvalueWcs () { 'valueWcs' }
sub XmNverifyBell () { 'verifyBell' }
sub XmNverticalFontUnit () { 'verticalFontUnit' }
sub XmNverticalScrollBar () { 'verticalScrollBar' }
sub XmNverticalSpacing () { 'verticalSpacing' }
sub XmNvisibleItemCount () { 'visibleItemCount' }
sub XmNvisibleWhenOff () { 'visibleWhenOff' }
sub XmNvisual () { 'visual' }
sub XmNvisualPolicy () { 'visualPolicy' }
sub XmNwaitForWm () { 'waitforwm' }
sub XmNwhichButton () { 'whichButton' }
sub XmNwidth () { 'width' }
sub XmNwidthInc () { 'widthInc' }
sub XmNwinGravity () { 'winGravity' }
sub XmNwindow () { 'window' }
sub XmNwindowGroup () { 'windowGroup' }
sub XmNwmTimeout () { 'wmTimeout' }
sub XmNwordWrap () { 'wordWrap' }
sub XmNworkWindow () { 'workWindow' }
sub XmNx () { 'x' }
sub XmNy () { 'y' }
1;
