package X11::LibCons;
package X;
sub XBufferOverflow () { -1 }
sub XLookupNone () { 1 }
sub XLookupChars () { 2 }
sub XLookupKeySym () { 3 }
sub XLookupBoth () { 4 }
sub None () { 0 }
sub ParentRelative () { 1 }
sub CopyFromParent () { 0 }
sub PointerWindow () { 0 }
sub InputFocus () { 1 }
sub PointerRoot () { 1 }
sub AnyPropertyType () { 0 }
sub AnyKey () { 0 }
sub AnyButton () { 0 }
sub AllTemporary () { 0 }
sub CurrentTime () { 0 }
sub NoSymbol () { 0 }
sub NoEventMask () { 0 }
sub KeyPressMask () { 1 }
sub KeyReleaseMask () { 2 }
sub ButtonPressMask () { 4 }
sub ButtonReleaseMask () { 8 }
sub EnterWindowMask () { 16 }
sub LeaveWindowMask () { 32 }
sub PointerMotionMask () { 64 }
sub PointerMotionHintMask () { 128 }
sub Button1MotionMask () { 256 }
sub Button2MotionMask () { 512 }
sub Button3MotionMask () { 1024 }
sub Button4MotionMask () { 2048 }
sub Button5MotionMask () { 4096 }
sub ButtonMotionMask () { 8192 }
sub KeymapStateMask () { 16384 }
sub ExposureMask () { 32768 }
sub VisibilityChangeMask () { 65536 }
sub StructureNotifyMask () { 131072 }
sub ResizeRedirectMask () { 262144 }
sub SubstructureNotifyMask () { 524288 }
sub SubstructureRedirectMask () { 1048576 }
sub FocusChangeMask () { 2097152 }
sub PropertyChangeMask () { 4194304 }
sub ColormapChangeMask () { 8388608 }
sub OwnerGrabButtonMask () { 16777216 }
sub KeyPress () { 2 }
sub KeyRelease () { 3 }
sub ButtonPress () { 4 }
sub ButtonRelease () { 5 }
sub MotionNotify () { 6 }
sub EnterNotify () { 7 }
sub LeaveNotify () { 8 }
sub FocusIn () { 9 }
sub FocusOut () { 10 }
sub KeymapNotify () { 11 }
sub Expose () { 12 }
sub GraphicsExpose () { 13 }
sub NoExpose () { 14 }
sub VisibilityNotify () { 15 }
sub CreateNotify () { 16 }
sub DestroyNotify () { 17 }
sub UnmapNotify () { 18 }
sub MapNotify () { 19 }
sub MapRequest () { 20 }
sub ReparentNotify () { 21 }
sub ConfigureNotify () { 22 }
sub ConfigureRequest () { 23 }
sub GravityNotify () { 24 }
sub ResizeRequest () { 25 }
sub CirculateNotify () { 26 }
sub CirculateRequest () { 27 }
sub PropertyNotify () { 28 }
sub SelectionClear () { 29 }
sub SelectionRequest () { 30 }
sub SelectionNotify () { 31 }
sub ColormapNotify () { 32 }
sub ClientMessage () { 33 }
sub MappingNotify () { 34 }
sub LASTEvent () { 35 }
sub ShiftMask () { 1 }
sub LockMask () { 2 }
sub ControlMask () { 4 }
sub Mod1Mask () { 8 }
sub Mod2Mask () { 16 }
sub Mod3Mask () { 32 }
sub Mod4Mask () { 64 }
sub Mod5Mask () { 128 }
sub ShiftMapIndex () { 0 }
sub LockMapIndex () { 1 }
sub ControlMapIndex () { 2 }
sub Mod1MapIndex () { 3 }
sub Mod2MapIndex () { 4 }
sub Mod3MapIndex () { 5 }
sub Mod4MapIndex () { 6 }
sub Mod5MapIndex () { 7 }
sub Button1Mask () { 256 }
sub Button2Mask () { 512 }
sub Button3Mask () { 1024 }
sub Button4Mask () { 2048 }
sub Button5Mask () { 4096 }
sub AnyModifier () { 32768 }
sub Button1 () { 1 }
sub Button2 () { 2 }
sub Button3 () { 3 }
sub Button4 () { 4 }
sub Button5 () { 5 }
sub NotifyNormal () { 0 }
sub NotifyGrab () { 1 }
sub NotifyUngrab () { 2 }
sub NotifyWhileGrabbed () { 3 }
sub NotifyHint () { 1 }
sub NotifyAncestor () { 0 }
sub NotifyVirtual () { 1 }
sub NotifyInferior () { 2 }
sub NotifyNonlinear () { 3 }
sub NotifyNonlinearVirtual () { 4 }
sub NotifyPointer () { 5 }
sub NotifyPointerRoot () { 6 }
sub NotifyDetailNone () { 7 }
sub VisibilityUnobscured () { 0 }
sub VisibilityPartiallyObscured () { 1 }
sub VisibilityFullyObscured () { 2 }
sub PlaceOnTop () { 0 }
sub PlaceOnBottom () { 1 }
sub FamilyInternet () { 0 }
sub FamilyDECnet () { 1 }
sub FamilyChaos () { 2 }
sub PropertyNewValue () { 0 }
sub PropertyDelete () { 1 }
sub ColormapUninstalled () { 0 }
sub ColormapInstalled () { 1 }
sub GrabModeSync () { 0 }
sub GrabModeAsync () { 1 }
sub GrabSuccess () { 0 }
sub AlreadyGrabbed () { 1 }
sub GrabInvalidTime () { 2 }
sub GrabNotViewable () { 3 }
sub GrabFrozen () { 4 }
sub AsyncPointer () { 0 }
sub SyncPointer () { 1 }
sub ReplayPointer () { 2 }
sub AsyncKeyboard () { 3 }
sub SyncKeyboard () { 4 }
sub ReplayKeyboard () { 5 }
sub AsyncBoth () { 6 }
sub SyncBoth () { 7 }
sub RevertToNone () { 0 }
sub RevertToPointerRoot () { 1 }
sub RevertToParent () { 2 }
sub Success () { 0 }
sub BadRequest () { 1 }
sub BadValue () { 2 }
sub BadWindow () { 3 }
sub BadPixmap () { 4 }
sub BadAtom () { 5 }
sub BadCursor () { 6 }
sub BadFont () { 7 }
sub BadMatch () { 8 }
sub BadDrawable () { 9 }
sub BadAccess () { 10 }
sub BadAlloc () { 11 }
sub BadColor () { 12 }
sub BadGC () { 13 }
sub BadIDChoice () { 14 }
sub BadName () { 15 }
sub BadLength () { 16 }
sub BadImplementation () { 17 }
sub FirstExtensionError () { 128 }
sub LastExtensionError () { 255 }
sub InputOutput () { 1 }
sub InputOnly () { 2 }
sub CWBackPixmap () { 1 }
sub CWBackPixel () { 2 }
sub CWBorderPixmap () { 4 }
sub CWBorderPixel () { 8 }
sub CWBitGravity () { 16 }
sub CWWinGravity () { 32 }
sub CWBackingStore () { 64 }
sub CWBackingPlanes () { 128 }
sub CWBackingPixel () { 256 }
sub CWOverrideRedirect () { 512 }
sub CWSaveUnder () { 1024 }
sub CWEventMask () { 2048 }
sub CWDontPropagate () { 4096 }
sub CWColormap () { 8192 }
sub CWCursor () { 16384 }
sub CWX () { 1 }
sub CWY () { 2 }
sub CWWidth () { 4 }
sub CWHeight () { 8 }
sub CWBorderWidth () { 16 }
sub CWSibling () { 32 }
sub CWStackMode () { 64 }
sub ForgetGravity () { 0 }
sub NorthWestGravity () { 1 }
sub NorthGravity () { 2 }
sub NorthEastGravity () { 3 }
sub WestGravity () { 4 }
sub CenterGravity () { 5 }
sub EastGravity () { 6 }
sub SouthWestGravity () { 7 }
sub SouthGravity () { 8 }
sub SouthEastGravity () { 9 }
sub StaticGravity () { 10 }
sub UnmapGravity () { 0 }
sub NotUseful () { 0 }
sub WhenMapped () { 1 }
sub Always () { 2 }
sub IsUnmapped () { 0 }
sub IsUnviewable () { 1 }
sub IsViewable () { 2 }
sub SetModeInsert () { 0 }
sub SetModeDelete () { 1 }
sub DestroyAll () { 0 }
sub RetainPermanent () { 1 }
sub RetainTemporary () { 2 }
sub Above () { 0 }
sub Below () { 1 }
sub TopIf () { 2 }
sub BottomIf () { 3 }
sub Opposite () { 4 }
sub RaiseLowest () { 0 }
sub LowerHighest () { 1 }
sub PropModeReplace () { 0 }
sub PropModePrepend () { 1 }
sub PropModeAppend () { 2 }
sub GXclear () { 0 }
sub GXand () { 1 }
sub GXandReverse () { 2 }
sub GXcopy () { 3 }
sub GXandInverted () { 4 }
sub GXnoop () { 5 }
sub GXxor () { 6 }
sub GXor () { 7 }
sub GXnor () { 8 }
sub GXequiv () { 9 }
sub GXinvert () { 10 }
sub GXorReverse () { 11 }
sub GXcopyInverted () { 12 }
sub GXorInverted () { 13 }
sub GXnand () { 14 }
sub GXset () { 15 }
sub LineSolid () { 0 }
sub LineOnOffDash () { 1 }
sub LineDoubleDash () { 2 }
sub CapNotLast () { 0 }
sub CapButt () { 1 }
sub CapRound () { 2 }
sub CapProjecting () { 3 }
sub JoinMiter () { 0 }
sub JoinRound () { 1 }
sub JoinBevel () { 2 }
sub FillSolid () { 0 }
sub FillTiled () { 1 }
sub FillStippled () { 2 }
sub FillOpaqueStippled () { 3 }
sub EvenOddRule () { 0 }
sub WindingRule () { 1 }
sub ClipByChildren () { 0 }
sub IncludeInferiors () { 1 }
sub Unsorted () { 0 }
sub YSorted () { 1 }
sub YXSorted () { 2 }
sub YXBanded () { 3 }
sub CoordModeOrigin () { 0 }
sub CoordModePrevious () { 1 }
sub Complex () { 0 }
sub Nonconvex () { 1 }
sub Convex () { 2 }
sub ArcChord () { 0 }
sub ArcPieSlice () { 1 }
sub GCFunction () { 1 }
sub GCPlaneMask () { 2 }
sub GCForeground () { 4 }
sub GCBackground () { 8 }
sub GCLineWidth () { 16 }
sub GCLineStyle () { 32 }
sub GCCapStyle () { 64 }
sub GCJoinStyle () { 128 }
sub GCFillStyle () { 256 }
sub GCFillRule () { 512 }
sub GCTile () { 1024 }
sub GCStipple () { 2048 }
sub GCTileStipXOrigin () { 4096 }
sub GCTileStipYOrigin () { 8192 }
sub GCFont () { 16384 }
sub GCSubwindowMode () { 32768 }
sub GCGraphicsExposures () { 65536 }
sub GCClipXOrigin () { 131072 }
sub GCClipYOrigin () { 262144 }
sub GCClipMask () { 524288 }
sub GCDashOffset () { 1048576 }
sub GCDashList () { 2097152 }
sub GCArcMode () { 4194304 }
sub GCLastBit () { 22 }
sub FontLeftToRight () { 0 }
sub FontRightToLeft () { 1 }
sub FontChange () { 255 }
sub XYBitmap () { 0 }
sub XYPixmap () { 1 }
sub ZPixmap () { 2 }
sub AllocNone () { 0 }
sub AllocAll () { 1 }
sub DoRed () { 1 }
sub DoGreen () { 2 }
sub DoBlue () { 4 }
sub CursorShape () { 0 }
sub TileShape () { 1 }
sub StippleShape () { 2 }
sub AutoRepeatModeOff () { 0 }
sub AutoRepeatModeOn () { 1 }
sub AutoRepeatModeDefault () { 2 }
sub LedModeOff () { 0 }
sub LedModeOn () { 1 }
sub KBKeyClickPercent () { 1 }
sub KBBellPercent () { 2 }
sub KBBellPitch () { 4 }
sub KBBellDuration () { 8 }
sub KBLed () { 16 }
sub KBLedMode () { 32 }
sub KBKey () { 64 }
sub KBAutoRepeatMode () { 128 }
sub MappingSuccess () { 0 }
sub MappingBusy () { 1 }
sub MappingFailed () { 2 }
sub MappingModifier () { 0 }
sub MappingKeyboard () { 1 }
sub MappingPointer () { 2 }
sub DontPreferBlanking () { 0 }
sub PreferBlanking () { 1 }
sub DefaultBlanking () { 2 }
sub DisableScreenSaver () { 0 }
sub DisableScreenInterval () { 0 }
sub DontAllowExposures () { 0 }
sub AllowExposures () { 1 }
sub DefaultExposures () { 2 }
sub ScreenSaverReset () { 0 }
sub ScreenSaverActive () { 1 }
sub HostInsert () { 0 }
sub HostDelete () { 1 }
sub EnableAccess () { 1 }
sub DisableAccess () { 0 }
sub StaticGray () { 0 }
sub GrayScale () { 1 }
sub StaticColor () { 2 }
sub PseudoColor () { 3 }
sub TrueColor () { 4 }
sub DirectColor () { 5 }
sub LSBFirst () { 0 }
sub MSBFirst () { 1 }
1;
