package X11::ToolkitCons;
package X::Toolkit;
sub XtSpecificationRelease () { 5 }
sub XtCWQueryOnly () { 128 }
sub XtSMDontChange () { 5 }
sub XtAllEvents () { -1 }
sub XtIMXEvent () { 1 }
sub XtIMTimer () { 2 }
sub XtIMAlternateInput () { 4 }
sub XtIMAll () { 7 }
sub XtListHead () { 0 }
sub XtListTail () { 1 }
sub XtInputNoneMask () { 0 }
sub XtInputReadMask () { 1 }
sub XtInputWriteMask () { 2 }
sub XtInputExceptMask () { 4 }
sub XtCallbackNoList () { 0 }
sub XtCallbackHasNone () { 1 }
sub XtCallbackHasSome () { 2 }
sub XtGeometryYes () { 0 }
sub XtGeometryNo () { 1 }
sub XtGeometryAlmost () { 2 }
sub XtGeometryDone () { 3 }
sub XtGrabNone () { 0 }
sub XtGrabNonexclusive () { 1 }
sub XtGrabExclusive () { 2 }
sub XtCacheNone () { 1 }
sub XtCacheAll () { 2 }
sub XtCacheByDisplay () { 3 }
sub XtCacheRefCount () { 256 }
sub XtUnspecifiedPixmap () { 2 }
sub XtUnspecifiedShellInt () { -1 }
sub XtUnspecifiedWindow () { 2 }
sub XtUnspecifiedWindowGroup () { 3 }
sub XtDefaultForeground () { 'XtDefaultForeground' }
sub XtDefaultBackground () { 'XtDefaultBackground' }
sub XtDefaultFont () { 'XtDefaultFont' }
sub XtDefaultFontSet () { 'XtDefaultFontSet' }
1;
